	PROGRAM PROG102

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY, 2009
C	WEST MIDLANDS, U.K


C	EQUILIBRIUM FLASH CALCULATIONS
C	THE PROGRAM USES THE ITERATIVE CONVERGENCE METHOD SUGGESTED BY
C	I.H. OLIVER AND LATER MODIFIED BY S.T. KOSTECKE TO CALCULATE
C	FLASH VAPORIZATION CONTAINING UP TO 15 COMPONENTS OF
C	MULTICOMPONENT MIXTURES OF OIL, GAS AND CHEMICAL PROCESSES.
C	THIS PROGRAM FURTHER CHECKS THE FEED COMPOSITION AT THE
C	CONDITIONS GIVEN TO DETERMINE WHETHER THE FEED IS ALL VAPOR
C	OR ALL LIQUID.	THIS PROGRAM IS BASED ON THE WELL-KNOWN AND
C	WIDELY USED VAPORIZATION EQUILIBRIUM RELATIONSHIPS THAT
C	APPEAR IN HANDBOOKS BY THE NATURAL GAS PROCESSORS SUPPILIERS
C	ASSOCIATIONS AND IN OTHER LITERATURE.
C	**************************************************************
C
C	Mi  = TOTAL MOLES OF COMPONENT i IN THE FEED STREAM
C	Ki  = EQUILIBRIUM FLASH CONSTANT FOR EACH COMPONENT i
C	      IN THE FEED STREAM
C	R   = L/V RATIO
C	R1  = NEW L/V RATIO FOR EACH ITERATIVE CALCULATION
C	L   = TOTAL MOLES OF LIQUID AT EQUILIBRIUM CONDITIONS
C	V   = TOTAL MOLES OF VAPOR AT EQUILIBRIUM CONDITIONS
C	Ni  = MOLES FRACTION OF COMPONENT i IN THE FEED STREAM
C	Li  = TOTAL MOLES OF COMPONENT i IN THE LIQUID PHASE
C	Vi  = TOTAL MOLES OF COMPONENT i IN THE VAPOR PHASE
C	X   = MOLE FRACTION OF FEED IN THE LIQUID PHASE AT EQUILIBRIUM
C	Y   = MOLE FRACTION OF FEED IN THE VAPOR PHASE AT EQUILIBRIUM
C	E,F = CONSTANTS USED BY KOSTECKS
C	***************************************************************
C

	DIMENSION C(15), V(15), X1(15), Y1(15)
	REAL K(15), L1, L(15), M(15), N(15)


	COMMON/DATA1/ NUM, T, P, M, K
	COMMON/DATA2/ ADD1, ADD2, ADD3

	OPEN (UNIT = 3, FILE='DATA72.DAT', STATUS='OLD', ERR=18)
	OPEN (UNIT = 1, FILE='PRN')

C	READ FLASH TEMPERATURE, oF			     = T
C	READ FLASH PRESSURE, psia			     = P
C	READ NUMBER OF COMPONENTS			     = NUM
C	READ FEED AND EQUILIBRIUM CONSTANT OF EACH COMPONENT = M, K

	READ (3, *, ERR=19) T
	READ (3, *, ERR=19) P
	READ (3, *, ERR=19) NUM

	DO I = 1, NUM
	READ (3, *, ERR=19) M(I), K(I)
	END DO

	GO TO 10

 18	WRITE (*, 100)
 100	FORMAT (5X, 'DATA FILE DOES NOT EXIST')
 
	GO TO 999

 19	WRITE (*, 110)
 110	FORMAT (5X, 'ERROR MESSAGE IN THE DATA VALUE')
 
	GO TO 999


 10	WRITE(1, 120)
 120	FORMAT(//,20X,'MULTICOMPONENT EQUILIBRIUM FLASH CALCULATIONS')


	SUM=0.0

	DO I = 1, NUM

	SUM = SUM + M(I)

	END DO

C	CALCULATE MOLE FRACTION OF COMPONENT IN THE FEED STREAM


	DO I = 1, NUM
	     N(I)=M(I)/SUM
	END DO

	TOTAL=0.0

	DO I = 1, NUM
	     TOTAL = TOTAL + N(I)
	END DO

C	CHECK WHETHER THE FEED IS ALL LIQUID OR VAPOR

	SUM1=0.0

	DO I1 = 1, NUM
	
	SUM1 = SUM1 + N(I1)*K(I1)
	
	END DO

	IF ( SUM1 .GT. 1.0) THEN
	
      	GO TO 45
      	
	ELSE
	
	     GO TO 900
	     
	ENDIF

 45	 SUM2 = 0.0

	DO I2 = 1, NUM
	
	    SUM2 = SUM2+N(I2)/K(I2)
	
	END DO

	IF(SUM2 .GT. 1.0) THEN

	     GO TO 60
	ELSE

	GO TO 1000

	ENDIF

C	GUESS R=L/V


 60	R=1.0
 65	SUM3=0.0

	DO I3 = 1, NUM
	
	C(I3)=(M(I3)*(K(I3)-1.0)*(R+1.0))/(K(I3)+R)
	
	END DO

C	CALCULATE E AND F CONSTANTS USED BY KOSTECKE.

	E = 0.0

	F = 0.0
	

	DO I4 = 1, NUM

	E = E+C(I4)

	F = F+(C(I4)**2/M(I4))

	END DO


C	CALCULATE R1, THE NEW L/V RATIO


	R1=ABS((F*R-E*(R+1.0))/(F+E*(R+1.0)))

	IF ( ABS(E) .LT. 0.001) THEN

      	GO TO 90

	ELSE

	     R=R1

	GO TO 65

	ENDIF

 90	L1 = 0.0

	V1 = 0.0

	DO I5 = 1, NUM

	L(I5) = (M(I5)*R1)/(K(I5)+R1)

	V(I5) = M(I5)-L(I5)

	L1 = L1 + L(I5)

	V1 = V1 + V(I5)

	END DO

	R2=L1/V1


C	CALCULATE X: MOLE FRACTION OF FEED IN THE LIQUID PHASE
C	AT EQUILIBRIUM, AND Y: MOLE FRACTION OF FEED IN THE VAPOR
C	PHASE AT EQUILIBRIUM.
C

	VAL1=0.0

	VAL2=0.0

	VAL3=0.0

	DO I6 = 1, NUM

	VAL1 = VAL1+L(I6)

	VAL2 = VAL2+M(I6)

	VAL3 = VAL3+V(I6)

	END DO


C	CALCULATE THE MOLE FRACTIONS IN THE LIQUID AND VAPOR PHASES.
C
	DO I = 1, NUM

	X1(I) =L(I)/VAL1

	Y1(I) =V(I)/VAL3

	END DO


C	CALCULATE THE TOTAL MOLE FRACTIONS OF THE FEED, LIQUID AND
C	VAPOR PHASES
C

	ADD1 = 0.0

	ADD2 = 0.0

	ADD3 = 0.0

	DO I = 1, NUM

	ADD1 = ADD1+X1(I)

	ADD2 = ADD2+N(I)

	ADD3 = ADD3+Y1(I)

	END DO
C
C	PRINT THE RESULTS ON THE SCREEN
C
	CALL OUTPUT(N, L, X1, V, Y1, VAL1, VAL2, VAL3)

C	PRINT THE RESULTS ONTO THE PRINTER

	CALL PAPER (N, L, X1, V, Y1, VAL1, VAL2, VAL3)

	GO TO 999

 900	WRITE(*,300)
 300	FORMAT(3X,'THE FEED COMPOSITION IS ALL LIQUID')

	GO TO 999


 1000	WRITE(*,400)
 400	FORMAT(3X,'THE FEED COMPOSITION IS ALL VAPOR')

	CLOSE (UNIT=3, STATUS='KEEP')

	CLOSE (UNIT=1)

 999	STOP
	END

C
C	***************************************************************
C	THIS PROGRAM OUTPUTS THE RESULTS ON THE SCREEN
C	****************************************************************
C
C
	SUBROUTINE OUTPUT (N, L, X1, V, Y1, VAL1, VAL2, VAL3)

	DIMENSION X1(15), Y1(15), V(15)

	REAL K(15), M(15), N(15), L(15)

	COMMON/DATA1/ NUM, T, P, M, K

	COMMON/DATA2/ ADD1, ADD2, ADD3

	WRITE(*, 130)
 130	FORMAT(2X,'MULTICOMPONENT EQUILIBRIUM FLASH CALCULATION AT '\)

	WRITE(*, 140) T, P
 140	FORMAT(F6.1,1X,'DEG. F',1X,'AND',1X,F6.1,1X,'PSIA')

	WRITE(*, 150)
 150	FORMAT(79(1H*))

	WRITE(*, 160)
 160	FORMAT(/,1X,'COMPONENT',1X,'K-VALUE',6X,'FEED',16X,'LIQUID ',\)

	WRITE(*, 170)
 170	FORMAT(15X,'VAPOR')

	WRITE(*, 180)
 180	FORMAT(1X,'NUMBER',12X,'Mols/h.',2X,'Mol. frac.',2X,'Mols/h.',\)

	WRITE(*, 190)
 190	FORMAT(2X,'Mol.frac.',2X,'Mols/h.',2X,'Mol.frac.')

	WRITE(*, 200)
 200	FORMAT(78(1H-))

	DO I = 1, NUM
	WRITE(*, 210) I, K(I), M(I), N(I), L(I), X1(I), V(I)
 210	FORMAT(1X,I2,5X,F5.3,2X,F9.3,2X,F8.3,3X,F9.3,2X,F8.3,2X,F9.3\)

	WRITE(*, 220) Y1(I)
 220	FORMAT(2X,F8.3)
	END DO

	WRITE(*, 230)
 230	FORMAT(78(1H-))

	WRITE(*, 240) VAL2, ADD2, VAL1, ADD1
 240	FORMAT(2X,'TOTALS',7X,F9.3,5X,F5.3,3X,F9.3,5X,F5.3,\)

	WRITE(*, 250) VAL3, ADD3
 250	FORMAT(2X,F9.3,5X,F5.3)

	WRITE(*, 260)
 260	FORMAT (78(1H-))
	RETURN
	END

C
C	***************************************************************
C	THIS PROGRAM PRINTS THE RESULTS ONTO THE PRINTER
C	***************************************************************

	SUBROUTINE PAPER (N, L, X1, V, Y1, VAL1, VAL2, VAL3)

	DIMENSION V(15), X1(15), Y1(15)

	REAL K(15), L(15), M(15), N(15)

	COMMON/DATA1/NUM, T, P, M, K

	COMMON/DATA2/ADD1, ADD2, ADD3

	WRITE (1, 270)
 270  FORMAT (/,2X,'MULTICOMPONENT EQUILIBRIUM FLASH CALCULATION AT ',\)

	WRITE (1, 280) T, P
 280	FORMAT (F6.1, 1X, 'DEG. F', 1X, 'AND', 1X, F6.1, 1X, 'psia')

	WRITE (1, 290)
 290	FORMAT (80(1H*))

	WRITE (1, 300)
 300  FORMAT (/, 1X,'COMPONENT', 1X,'K-VALUE',6X,'FEED',16X,'LIQUID ',\)

	WRITE (1, 310)
 310	FORMAT (15X, 'VAPOR')

	WRITE (1, 320)
 320  FORMAT (1X, 'NUMBER',12X,'Mols/h.',2X,'Mol. frac.',2X,'Mols/h.',\)

	WRITE (1, 330)
 330	FORMAT (2X,'Mol. frac.', 2X, 'Mols/h.', 2X,'Mol. frac.')

	WRITE (1, 340)
 340	FORMAT (80(1H-))

	DO I = 1, NUM

	WRITE (1, 350) I, K(I), M(I), N(I), L(I), X1(I), V(I)
 350	FORMAT (1X,I2,5X,F5.3,2X,F9.3,2X,F8.3,3X,F9.3,2X,F8.3,2X,F9.3,\)

	WRITE (1, 360) Y1(I)
 360	FORMAT (2X,F8.3)

	END DO

	WRITE (1, 370)
 370	FORMAT (80(1H-))

	WRITE (1, 380) VAL2, ADD2, VAL1, ADD1
 380	FORMAT (2X,'TOTALS', 7X, F9.3, 5X, F5.3, 3X, F9.3, 5X, F5.3,\)

	WRITE (1, 390) VAL3, ADD3
 390	FORMAT (2X, F9.3, 5X, F5.3)

	WRITE (1, 400)
 400	FORMAT (80(1H-))


	RETURN
	END
