	PROGRAM PROG103

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY, 2009
C	WEST MIDLANDS, U.K.


C	NUMBER OF STAGES AT LOW CONCENTRATIONS.
C	THIS PROGRAM CALCULATES THE NUMBER OF EQUILIBRIUM STAGES
C	USING THE SMOKER EQUATIONS.
C	IN THE LOW-CONCENTRATION REGION THE EQUILIBRIUM RELATION FOLLOWS
C	HENRY'S LAW AND Y=KX, AND THIS RELATIONSHIP IS USED TO PLOT THE
C	EQUILIBRIUM LINE IF DATA ARE NOT AVAILABLE.  THE EQUATIONS
C	DEVELOPED BY SMOKER WILL HANDLE THESE OPERATIONS ANALYTICALLY.
C
C	******************************************************************
C	A1	=   AVERAGE RELATIVE VOLATILITY OF THE RECTIFYING SECTION
C	A2	=   AVERAGE RELATIVE VOLATILITY OF THE STRIPPING SECTION
C	R	=   REFLUX RATIO
C	XF	=   MOLE FRACTION OF THE FEED
C	XD	=   MOLE FRACTION OF THE TOP PRODUCT
C	XB	=   MOLE FRACTION OF THE BOTTOMS PRODUCT
C	N1	=   NUMBER OF STAGES IN THE RECTIFYING SECTION
C	N2	=   NUMBER OF STAGES IN THE STRIPPING SECTION
C	TOTAL	=   THE TOTAL NUMBER OF STAGES.
C	POST	=   THE OPTIMUM FEED STAGE LOCATION.
C	*******************************************************************
C
C
	REAL K,K1,K2,N1,N2

	COMMON/MASS/K1,K2


	OPEN (UNIT=3, FILE='DATA103.DAT', STATUS='OLD', ERR=18)
	
	OPEN (UNIT=1, FILE='RES103.RES')

C	READ THE RELATIVE VOLATILITIES OF THE TWO COMPONENTS A1, A2.
C	READ THE MOLE FRACTION OF THE FEED, XF.
C	READ THE MOLE FRACTION OF THE DISTILLATE, XD.
C	READ THE MOLE FRACTION OF THE BOTTOMS, XB.
C	READ THE REFLUX RATIO, R.


	READ (3, *, ERR=19) A1, A2
	READ (3, *, ERR=19) XF, XD, XB
	READ (3, *, ERR=19) R

	GO TO 5

 18	WRITE (*, 23)
 23	FORMAT (5X,'DATA FILE DOES NOT EXIST')
	GO TO 999

 19	WRITE (*, 29)
 29	FORMAT (5X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999


 5	WRITE (1, 100)
 100  FORMAT(/,15X,49HEQUILIBRIUM NUMBER OF STAGES BY SMOKER'S EQUATION,
     *	/1H ,78(1H*))

	WRITE (1, 110) A1, A2
 110	FORMAT(5X,'THE RELATIVE VOLATILITY OF COMPONENT 1.:', T60,
     *		 F10.3,/,5X,'THE RELATIVE VOLATILITY OF COMPONENT 2.:',
     *		 T60,F10.3)

	WRITE (1, 120) XF, XD, XB, R
 120	FORMAT(5X,'THE MOLE FRACTION OF THE FEED:', T60, F10.4,/,
     *	       5X,'THE MOLE FRACTION OF THE DISTILLATE:', T60, F10.4,/,
     *	       5X,'THE MOLE FRACTION OF THE BOTTOMS:', T60, F10.4,/,
     *	       5X,'THE REFLUX RATIO:', T60, F10.2)


	WRITE (*, 130)
 130  FORMAT(/,15X,49HEQUILIBRIUM NUMBER OF STAGES BY SMOKER'S EQUATION,
     *	/1H ,78(1H*))

	WRITE (*, 140) A1, A2
 140	FORMAT(5X,'THE RELATIVE VOLATILITY OF COMPONENT 1.:', T60,
     *		 F10.3,/,5X,'THE RELATIVE VOLATILITY OF COMPONENT 2.:',
     *		 T60,F10.3)

	WRITE (*, 150) XF, XD, XB, R
 150	FORMAT(5X,'THE MOLE FRACTION OF THE FEED:', T60, F10.4,/,
     *	       5X,'THE MOLE FRACTION OF THE DISTILLATE:', T60, F10.4,/,
     *	       5X,'THE MOLE FRACTION OF THE BOTTOMS:', T60, F10.4,/,
     *	       5X,'THE REFLUX RATIO:', T60, F10.2)


	GO TO 10

C	CALCULATE THE NUMBER OF STAGES IN THE RECTIFYING SECTION

 10	S1=R/(R+1.0)
	B1=XD/(R+1.0)


C	CALCULATE  K, THE VALUE OF THE X-ORDINATE AT THE POINT WHERE
C	THE EXTENDED OPERATING LINE INTERSECT THE VAPOUR-LIQUID
C	EQUILIBRIUM CURVE FROM THE QUADRATIC EQUATION AX^2+BX+C=0

C	CALCULATE THE CO-EFFICIENTS OF THE QUADRATIC EQUATION IN
C	THE RECTIFYING SECTION

	A = S1*(A1-1.0)
	B = S1+B1*(A1-1.0)-A1
	C = B1

C	SOLVE THE QUADRATIC EQUATION

	CALL PROG1 (A, B, C, K)

C	CALCULATE THE NUMBER OF STAGES IN THE RECTIFYING SECTION, N1


	C1 = 1.0+(A1-1.0)*K
	X1 = XD-K
	X2 = XF-K
	BETA1 = (S1*C1*(A1-1.0))/(A1-(S1*(C1**2)))
	VAL1 = (X1*(1.0-(BETA1*X2)))/(X2*(1.0-(BETA1*X1)))
	VAL2 = A1/(S1*(C1**2))

C	CALCULATE THE NUMBER OF STAGES IN THE RECTIFYING SECTION.

	N1=ALOG(VAL1)/ALOG(VAL2)

	WRITE (1, 135) N1
 135	FORMAT(5X,'THE NUMBER OF STAGES IN THE RECTIFYING SECTION:',
     *	       T60, F8.2)


	WRITE (*, 145) N1
 145	FORMAT(5X,'THE NUMBER OF STAGES IN THE RECTIFYING SECTION:',
     *	       T60, F8.2)




C	CALCULATE THE NUMBER OF STAGES IN THE STRIPPING SECTION, N2


	S2 = ((R*XF)+XD-(R+1.0)*XB)/((R+1.0)*(XF-XB))
	B2 = ((XF-XD)*XB)/((R+1.0)*(XF-XB))

C	CALCULATE THE CO-EFFICIENTS OF THE QUADRATIC EQUATION AX^2+BX+C=0
C	IN THE STRIPPING SECTION


	A = S2*(A2-1.0)
	B = (S2+B2*(A2-1.0)-A2)
	C = B2

C	CALCULATE THE NUMBER OF STAGES IN THE RECTIFYING SECTION.

	CALL PROG1 (A, B, C, K)

	X3 = XF-K
	X4 = XB-K
	C2 = 1.0+(A2-1.0)*K
	BETA2 = (S2*C2*(A2-1.0))/(A2-(S2*(C2**2)))
	VAL3 = (X3*(1.0-(BETA2*X4)))/(X4*(1.0-(BETA2*X3)))
	VAL4 = A2/(S2*(C2**2))

	N2 = ALOG(VAL3)/ALOG(VAL4)

	WRITE (1, 160) N2
 160	FORMAT(5X,'THE NUMBER OF STAGES IN THE STRIPPING SECTION:',
     *	     T60, F8.2)

	TOTAL = N1+N2

	WRITE (1, 170) TOTAL
 170	FORMAT(5X,'TOTAL NUMBER OF STAGES:', T60, F8.2)



	WRITE (*, 165) N2
 165	FORMAT(5X,'THE NUMBER OF STAGES IN THE STRIPPING SECTION:',
     *	     T60, F8.2)


	WRITE (*, 175) TOTAL
 175	FORMAT(5X,'TOTAL NUMBER OF STAGES:', T60, F8.2)


C	THE FEED LOCATION IS THAT FROM THE STRIPPING SECTION TO
C	THE BOTTOM OF THE COLUMN.

	POST = N2

	WRITE (1, 180) POST
 180	FORMAT (5X,'FEED STAGE LOCATION:', T60, F8.1)


	WRITE (*, 185) POST
 185	FORMAT (5X,'FEED STAGE LOCATION:', T60, F8.1)



	WRITE (1, 190)
 190	FORMAT (78(1H-))

 	WRITE (*, 195)
 195	FORMAT (78(1H-))



	CLOSE (3,STATUS='KEEP')
	
	CLOSE (1)

 999	STOP
	END
C
C	***************************************************************
C	THIS PROGRAM SOLVES THE QUADRATIC EQUATION AX^2+BX+C=0 IN THE
C	RECTIFYING AND STRIPPING SECTIONS
C	***************************************************************

	SUBROUTINE PROG1 (A, B, C, K)

	REAL K,K1,K2
	COMMON/MASS/K1,K2

	D = (B**2-4.0*A*C)

	IF ( D .LT. 0.0) THEN

	GO TO 10

	ELSE

	K1= (-B+SQRT(D))/(2.0*A)

	K2= (-B-SQRT(D))/(2.0*A)

	ENDIF

	IF (K1 .LT. 0.0 .OR. K1 .GT. 1.0) THEN
	
	GO TO 20
	
	ELSE
	
	K = K1
	
	GO TO 30
	
	ENDIF

 20	IF (K2 .LT. 0.0 .OR. K2 .GT. 1.0) THEN
 
	GO TO 40

	ELSE

	K=K2

	GO TO 30

	ENDIF

 40	WRITE (*, 190)
 190	FORMAT(6X,'ROOTS ARE OUT OF LIMITS CHECK PROBLEM SPECIFICATION')
     
     	GO TO 30
	
 10	WRITE (*, 200)
 200	FORMAT(6X,'IMAGINARY ROOTS, CHECK PROBLEM SPECIFICATION')
 
 30	RETURN

	END
