	PROGRAM PROG74

C	BY A.K. COKER
C	GULF PUBLISHING COMPANY 1994
C	HOUSTON, TEXAS 77252


C	PACKED-TOWER SIZING
C	THE TOWER SIZING METHOD IS BASED ON THE GENERALIZED PRESSURE
C	DROP CORRELATION OF SHERWOOD, SHIPLEY AND HOLLOWAY AND
C	REPLOTTED IN FIGURE GR-109 R-5 BY NORTON CO.  THIS CORRELATION
C	IS A PLOT OF X .VS. Y FOR PRESSURE DROP CURVES RANGING FROM
C	0.5 TO 1.5 INCH OF WATER.  FROM THESE CURVES THE TOWER DIAMETER
C	CAN BE EVALUATED.
C	***************************************************************
C
C	L	=   LIQUID RATE, lb/h
C	G	=   VAPOR RATE, lb/h
C	DG	=   VAPOR DENSITY, lb/ft^3
C	DL	=   LIQUID DENSITY, lb/ft^3
C	X	=   X CO-ORDINATE IN GR-109 R-5 PLOT
C	Y	=   Y CO-ORDINATE IN GR-109 R-5 PLOT
C	G1	=   VAPOR RATE, lb/s.ft^2
C	PF	=   PACKING FACTOR FOR PACKING USED
C	LVIS	=   LIQUID VISCOSITY, cP
C	GC	=   GRAVITATIONAL CONSTANT = 32.2 ft/s^2
C	AREA	=   TOWER AREA, ft^2
C	DIA	=   TOWER DIAMTER, ft
C	DELP	=   PRESSURE DROP inch H2O/ft.
C	PI	=   CONSTANT = 3.1415927
C	***************************************************************


	COMMON/TOWER1/ GC, PI
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF
	REAL L, LVIS

	OPEN (UNIT = 3, FILE='DATA74.DAT', STATUS='OLD', ERR=18)
	OPEN (UNIT = 1, FILE='PRN')




C	READ LIQUID FLOW RATE, lb/hr.		=   L
C	READ GAS FLOW RATE, lb/hr.		=   G
C	READ GAS DENSITY, lb/ft^3.		=   DG
C	READ LIQUID DENSITY, lb/ft^3.		=   DL
C	READ TOWER PACKING FACTOR		=   PF
C	READ PRESSURE DROP, inch-H2O/ft.	=   DELP
C	READ LIQUID VISCOSITY, cP.		=   LVIS

	READ (3, *, ERR =19) L, G, DG
	READ (3, *, ERR =19) DL, PF, DELP, LVIS

	GO TO 10

 18	WRITE (*, 100)
 100	FORMAT (5X, 'DATA FILE DOES NOT EXIST')
	GO TO 999

 19	WRITE (*, 110)
 110	FORMAT (5X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999


 10	PI = 3.1415927
	GC = 32.2

C	WHERE 0.01 < X < 2.0
	SUM1=DG/(DL-DG)
	X = L/G*SQRT(SUM1)


	IF (DELP .EQ. 0.05) THEN
	GO TO 30

	ELSEIF(DELP .EQ. 0.10) THEN
	GO TO 35

	ELSEIF(DELP .EQ. 0.25) THEN
	GO TO 40

	ELSEIF(DELP .EQ. 0.50) THEN
	GO TO 45

	ELSEIF(DELP .EQ. 1.0) THEN
	GO TO 50

	ELSEIF(DELP .EQ. 1.5) THEN
	GO TO 55

	ENDIF


   30	CALL PROG1 (L, G, DG, DL, PF, LVIS)

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT (L, G, DG, DL, PF, DELP, LVIS)

C	PRINT THE RESULTS ONTO A PRINTER

	CALL PAPER (L, G, DG, DL, PF, DELP, LVIS)

	GO TO 999

   35	CALL PROG2 (L, G, DG, DL, PF, LVIS)

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT (L, G, DG, DL, PF, DELP, LVIS)

C	PRINT THE RESULTS ONTO A PRINTER

	CALL PAPER (L, G, DG, DL, PF, DELP, LVIS)
	GO TO 999

   40	CALL PROG3 (L, G, DG, DL, PF, LVIS)

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT (L, G, DG, DL, PF, DELP, LVIS)

C	PRINT THE RESULTS ONTO A PRINTER

	CALL PAPER (L, G, DG, DL, PF, DELP, LVIS)
	GO TO 999

   45	CALL PROG4 (L, G, DG, DL, PF, LVIS)

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT (L, G, DG, DL, PF, DELP, LVIS)

C	PRINT THE RESULTS ONTO A PRINTER

	CALL PAPER (L, G, DG, DL, PF, DELP, LVIS)
	GO TO 999

   50	CALL PROG5 (L, G, DG, DL, PF, LVIS)


C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT (L, G, DG, DL, PF, DELP, LVIS)

C	PRINT THE RESULTS ONTO A PRINTER

	CALL PAPER (L, G, DG, DL, PF, DELP, LVIS)
	GO TO 999

   55	CALL PROG6 (L, G, DG, DL, PF, LVIS)

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT (L, G, DG, DL, PF, DELP, LVIS)

C	PRINT THE RESULTS ONTO A PRINTER

	CALL PAPER (L, G, DG, DL, PF, DELP, LVIS)
	GO TO 999


	CLOSE (UNIT = 3, STATUS='KEEP')
	CLOSE (UNIT = 1)

 999	STOP
	END
C
C
C	***************************************************************
C	PACKED-TOWER SIZING WITH A PRESSURE DROP OF 0.05 inch H2O/ft
C	***************************************************************

	SUBROUTINE PROG1 (L, G, DG, DL, PF, LVIS)
	REAL L,LVIS

	COMMON/TOWER1/ GC, PI
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF

C	CONSTANTS FOR DELP=0.05

	C0 = -6.30253
	C1 = -0.60809
	C2 = -0.11932
	C3 = -0.00685
	C4 = 0.000320

C	WHERE 0.001  < Y < 0.15

	SUM1 = ALOG(X)
	SUM2 = (ALOG(X))**2
	SUM3 = (ALOG(X))**3
	SUM4 = (ALOG(X))**4
	SUMT = C0+(C1*SUM1)+(C2*SUM2)+(C3*SUM3)+(C4*SUM4)

	Y1 = EXP(SUMT)

C	CALCULATE VAPOR RATE lb/s.ft^2

	VAL1 = Y1*DG*(DL-DG)*GC
	VAL2 = PF*(LVIS)**0.1
	RATIO = VAL1/VAL2
	G1 = (RATIO)**0.5

C	CALCULATE TOWER AREA AND TOWER DIAMETER

	AREA = G/(3600.*G1)
	DIA = 12.0*((4.0*AREA)/PI)**0.5

C	CALCULATE Y  CO-ORDINATE IN GR-109 R-5 PLOT

	VAL3 = (G1**2)*PF*(LVIS)**0.1
	VAL4 = DG*(DL-DG)*GC
	Y = VAL3/VAL4

C	CALCULATE THE PACKED TOWER FLOODING CONDITIONS

	CALL FLOOD (L, G, DG, DL, PF, LVIS)

	RETURN
	END

C	***************************************************************
C	PACKED-TOWER SIZING WITH A PRESSURE DROP OF 0.10 inch H2O/ft
C	***************************************************************

	SUBROUTINE PROG2 (L, G, DG, DL, PF, LVIS)

	REAL L,LVIS
	COMMON/TOWER1/ GC, PI
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF

C	CONSTANTS FOR DELP=0.1

	C0 = -5.50093
	C1 = -0.78508
	C2 = -0.13496
	C3 =  0.00134
	C4 =  0.00174

C	WHERE 0.001 < Y < 0.15

	SUM1 = ALOG(X)
	SUM2 = (ALOG(X))**2
	SUM3 = (ALOG(X))**3
	SUM4 = (ALOG(X))**4
	SUMT = C0+(C1*SUM1)+(C2*SUM2)+(C3*SUM3)+(C4*SUM4)
	Y1 = EXP(SUMT)

C	CALCULATE VAPOR RATE, lb/s.ft^2

	VAL1 = Y1*DG*(DL-DG)*GC
	VAL2 = PF*(LVIS)**0.1
	RATIO = VAL1/VAL2
	G1 = (RATIO)**0.5

C	CALCULATE TOWER AREA AND TOWER DIAMETER

	AREA = G/(3600.*G1)
	DIA = 12.0*((4.0*AREA)/PI)**0.5

C	CALCULATE Y  CO-ORDINATE IN GR-109 R-5 PLOT

	VAL3 = (G1**2)*PF*(LVIS)**0.1
	VAL4 = DG*(DL-DG)*GC
	Y = VAL3/VAL4


C	CALCULATE THE PACKED TOWER FLOODING CONDITIONS.

	CALL FLOOD (L, G, DG, DL, PF, LVIS)

	RETURN
	END

C	***************************************************************
C	PACKED-TOWER SIZING WITH A PRESSURE DROP OF 0.25 inch H2O/ft
C	***************************************************************

	SUBROUTINE PROG3 (L, G, DG, DL, PF, LVIS)

	REAL L, LVIS
	COMMON/TOWER1/ GC, PI
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF

C	CONSTANTS FOR DELP=0.25

	C0 = -5.00319
	C1 = -0.95299
	C2 = -0.13930
	C3 =  0.01264
	C4 =  0.00334

C	WHERE 0.001 < Y < 0.15

	SUM1 = ALOG(X)
	SUM2 = (ALOG(X))**2
	SUM3 = (ALOG(X))**3
	SUM4 = (ALOG(X))**4
	SUMT = C0+(C1*SUM1)+(C2*SUM2)+(C3*SUM3)+(C4*SUM4)
	Y1 = EXP(SUMT)

C	CALCULATE VAPOR RATE, lb/s.ft^2

	VAL1 = Y1*DG*(DL-DG)*GC
	VAL2 = PF*(LVIS)**0.1
	RATIO = VAL1/VAL2
	G1 = SQRT(RATIO)

C	CALCULATE TOWER AREA AND TOWER DIAMETER

	AREA = G/(3600.0*G1)
	DIA = 12.0*SQRT((4.0*AREA)/PI)

C	CALCULATE Y  CO-ORDINATE IN GR-109 R-5 PLOT

	VAL3 = (G1**2)*PF*(LVIS)**0.1
	VAL4 = DG*(DL-DG)*GC
	Y = VAL3/VAL4

C	CALCULATE THE PACKED TOWER FLOODING CONDITONS.

	CALL FLOOD (L, G, DG, DL, PF, LVIS)
	RETURN
	END

C	***************************************************************
C	PACKED TOWER SIZING WITH A PRESSURE DROP OF 0.5 inch H2O/ft
C	***************************************************************

	SUBROUTINE PROG4 (L, G, DG, DL, PF, LVIS)

	REAL L,LVIS
	COMMON/TOWER1/ GC, PI
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF

C	CONSTANTS FOR DELP=0.5

	C0 = -4.39918
	C1 = -0.99404
	C2 = -0.16983
	C3 =  0.00873
	C4 =  0.00343

C	WHERE 0.001 < Y < 0.15

	SUM1 = ALOG(X)
	SUM2 = (ALOG(X))**2
	SUM3 = (ALOG(X))**3
	SUM4 = (ALOG(X))**4
	SUMT = C0+(C1*SUM1)+(C2*SUM2)+(C3*SUM3)+(C4*SUM4)
	Y1 = EXP(SUMT)

C	CALCULATE VAPOR RATE, lb/s.ft^2

	VAL1 = Y1*DG*(DL-DG)*GC
	VAL2 = PF*(LVIS)**0.1
	RATIO = VAL1/VAL2
	G1 = (RATIO)**0.5

C	CALCULATE TOWER AREA AND TOWER DIAMETER

	AREA = G/(3600.*G1)
	DIA = 12.0*((4.0*AREA)/PI)**0.5

C	CALCULATE Y  CO-ORDINATE IN GR-109 R-5 PLOT

	VAL3 = (G1**2)*PF*(LVIS)**0.1
	VAL4 = DG*(DL-DG)*GC
	Y = VAL3/VAL4

C	CALCULATE THE PACKED TOWER FLOODING CONDITIONS.

	CALL FLOOD (L, G, DG, DL, PF, LVIS)
	RETURN
	END

C	***************************************************************
C	PACKED-TOWER SIZING WITH A PRESSURE DROP OF 1 inch H2O/ft.
C	***************************************************************

	SUBROUTINE PROG5 (L, G, DG, DL, PF, LVIS)

	REAL L,LVIS

	COMMON/TOWER1/ GC, PI
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF

C	CONSTANTS FOR DELP=1.0

	C0 = -4.09505
	C1 = -1.00120
	C2 = -0.15871
	C3 =  0.00797
	C4 =  0.00318

C	WHERE 0.001 < Y < 0.15

	SUM1 = ALOG(X)
	SUM2 = (ALOG(X))**2
	SUM3 = (ALOG(X))**3
	SUM4 = (ALOG(X))**4
	SUMT = C0+(C1*SUM1)+(C2*SUM2)+(C3*SUM3)+(C4*SUM4)
	Y1 = EXP(SUMT)

C	CALCULATE VAPOR RATE, lb/s.ft^2

	VAL1 = Y1*DG*(DL-DG)*GC
	VAL2 = PF*(LVIS)**0.1
	RATIO = VAL1/VAL2
	G1 = (RATIO)**0.5

C	CALCULATE TOWER AREA AND TOWER DIAMETER

	AREA = G/(3600.*G1)
	DIA = 12.0*((4.0*AREA)/PI)**0.5

C	CALCULATE Y  CO-ORDINATE IN GR-109 R-5 PLOT

	VAL3 = (G1**2)*PF*(LVIS)**0.1
	VAL4 = DG*(DL-DG)*GC
	Y = VAL3/VAL4

C	CALCULATE THE PACKED TOWER FLOODING CONDITIONS.


	CALL FLOOD (L, G, DG, DL, PF, LVIS)
	RETURN
	END

C	***************************************************************
C	PACKED-TOWER SIZING WITH A PRESSURE DROP OF 1.5 inch H2O/ft.
C	***************************************************************

	SUBROUTINE PROG6 (L, G, DG, DL, PF, LVIS)

	REAL L, LVIS
	COMMON/TOWER1/ GC, PI
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF

C	CONSTANTS FOR DELP=1.5

	C0 = -4.02555
	C1 = -0.98945
	C2 = -0.08291
	C3 = -0.03237
	C4 =  0.00532

C	WHERE 0.001 < Y < 0.15

	SUM1 = ALOG(X)
	SUM2 = (ALOG(X))**2
	SUM3 = (ALOG(X))**3
	SUM4 = (ALOG(X))**4
	SUMT = C0+(C1*SUM1)+(C2*SUM2)+(C3*SUM3)+(C4*SUM4)
	Y1 = EXP(SUMT)

C	CALCULATE VAPOR RATE lb/s.ft^2

	VAL1 = Y1*DG*(DL-DG)*GC
	VAL2 = PF*(LVIS)**0.1
	RATIO = VAL1/VAL2
	G1 = (RATIO)**0.5

C	CALCULATE TOWER AREA AND TOWER DIAMETER

	AREA = G/(3600.*G1)
	DIA = 12.0*((4.0*AREA)/PI)**0.5

C	CALCULATE Y CO-ORDINATE IN GR-109 R-5 PLOT

	VAL3 = (G1**2)*PF*(LVIS)**0.1
	VAL4 = DG*(DL-DG)*GC
	Y = VAL3/VAL4

C	CALCULATE THE PACKED TOWER FLOODING CONDITIONS.

	CALL FLOOD (L, G, DG, DL, PF, LVIS)
	RETURN
	END

C	***************************************************************
C	THIS PROGRAM CALCULATES THE VAPOR RATE AT FLOODING CONDITION
C	***************************************************************

	SUBROUTINE FLOOD (L, G, DG, DL, PF, LVIS)

	REAL L,LVIS
	COMMON/TOWER1/ GC, PI
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF
C
	X1 = (L/G)*SQRT(DG/DL)
	TI = 62.4/DL
	Y1=10.0**(-1.6678-(1.085*ALOG10(X1))-(0.29655*(ALOG10(X1))**2))
	VAL1 = Y1*DL*DG*GC
	VAL2 = PF*TI*(LVIS)**2
	RATIO = VAL1/VAL2
	G2 = SQRT(RATIO)

C	CALCULATE VAPOR RATE AT 70% OF FLOODING CONDITION

	G2 = 0.7*G2

C	CALCULATE VAPOR VELOCITY AT 70% FLOODING CONDITION

	VG=G2/DG

C	CALCULATE THE TOWER AREA AT 70% FLOODING CONDITION.

C	SINCE THE FLOODING CORRELATION IS NOT PERFECT, HENCE
C	TO HAVE A 95% CONFIDENCE, USE A SAFETY FACTOR OF 1.32
C	FOR THE CALCULATED CROSS-SECTIONAL AREA (Bolles and Fair,
C	Chem. Eng., 89 (14), 109 (July 12, 1982).

	AREAF = 1.32*(G/(3600.0*G2))

C	CALCULATE THE TOWER DIAMETER AT 70% FLOODING CONDITION

	DIAF = SQRT((4.0*AREAF)/PI)

C	DIAMETER IN inches:

	DIAF = 12.0*DIAF

	RETURN
	END

C	****************************************************************
C	THIS PROGRAM OUTPUTS THE RESULTS ON THE SCREEN
C	****************************************************************

	SUBROUTINE OUTPUT (L, G, DG, DL, PF, DELP, LVIS)

	REAL L,LVIS
	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF

	WRITE (*, 120)
 120	FORMAT(20X,'PACKED TOWER DESIGN')

	WRITE (*, 130)
 130	FORMAT(78(1H*))

	WRITE (*, 140) L
 140	FORMAT(5X,'LIQUID FLOW RATE, lb/hr.:', T60, F12.3)

	WRITE (*, 150) G
 150	FORMAT(5X,'GAS FLOW RATE, lb/hr.:', T60, F12.3)

	WRITE (*, 160) DG
 160	FORMAT(5X,'GAS DENSITY, lb/ft^3:', T60, F8.4)

	WRITE (*, 170) DL
 170	FORMAT(5X,'LIQUID DENSITY, lb/ft^3:', T60, F8.4)

	WRITE (*, 180) PF
 180	FORMAT(5X,'TOWER PACKING FACTOR:', T60, F8.1)

	WRITE (*, 190) DELP
 190	FORMAT(5X,'PRESSURE DROP, inch H2O/ft:', T60, F8.3)

	WRITE (*, 200) LVIS
 200	FORMAT(5X,'LIQUID VISCOSITY, cP:', T60, F8.3)

	WRITE (*, 210) X
 210	FORMAT(5X,'X CO-ORDINATE IN THE GENERALIZED PLOT:', T60, F8.4)

	WRITE (*, 220) Y
 220	FORMAT(5X,'Y CO-ORDINATE IN THE GENERALIZED PLOT:', T60, F8.4)

	WRITE (*, 230) G1
 230	FORMAT(5X,'CALCULATED VAPOR RATE, lb/s.ft^2:', T60, F8.4)

	WRITE (*, 240) X1
 240	FORMAT(5X,'X CO-ORDINATE AT FLOODING CONDITION:', T60, F8.4)

	WRITE (*, 250) Y1
 250	FORMAT(5X,'Y CO-ORDINATE AT FLOODING CONDITION:', T60, F8.4)

	WRITE (*, 260) G2
 260	FORMAT(5X,'VAPOR RATE AT 70% FLOODING CONDITION, lb/s.ft^2:',\,
     *	       T60, F8.4)

	WRITE (*, 270) VG
 270	FORMAT(5X,'VAPOR VELOCITY AT 70% FLOODING CONDITION, ft./s.:',\,
     *	       T60, F8.2)

	WRITE (*, 280) AREA
 280	FORMAT(5X,'TOWER AREA, ft^2:' T60, F8.2)

	WRITE (*, 290) DIA
 290	FORMAT(5X,'TOWER DIAMETER, inches:', T60, F8.2)

	WRITE (*, 300) AREAF
 300	FORMAT(5X,'TOWER AREA AT 70% FLOODING CONDITION, ft^2:',T60,F8.2)

	WRITE (*, 310) DIAF
 310   FORMAT(5X,'TOWER DIAMETER AT 70% FLOODING CONDITION, inches:',\,
     *	     T60, F8.2)

	WRITE (*, 320)
 320	FORMAT (78(1H-))
	RETURN
	END
C
C	******************************************************************
C	THIS PROGRAM PRINTS THE RESULTS ONTO A PRINTER
C	******************************************************************

	SUBROUTINE PAPER (L, G, DG, DL, PF, DELP, LVIS)

	REAL L, LVIS

	COMMON/TOWER2/ X, Y, X1, Y1
	COMMON/TOWER3/ AREA, DIA
	COMMON/TOWER4/ G1, G2, VG
	COMMON/TOWER5/ AREAF, DIAF

	WRITE (1, 330)
 330	FORMAT (///,25X,'PACKED TOWER DESIGN')

	WRITE (1, 340)
 340	FORMAT (78(1H*))

	WRITE (1, 350) L
 350	FORMAT (5X,'LIQUID FLOW RATE, lb/hr.:', T60, F12.3)

	WRITE (1, 360) G
 360	FORMAT (5X,'GAS FLOW RATE, lb/hr.:', T60, F12.3)

	WRITE (1, 370) DG
 370	FORMAT (5X,'GAS DENSITY, lb/ft.^3:', T60, F8.4)

	WRITE (1, 380) DL
 380	FORMAT (5X,'LIQUID DENSITY, lb/ft.^3:', T60, F8.4)

	WRITE (1, 390) PF
 390	FORMAT (5X,'TOWER PACKING FACTOR:', T60, F8.1)

	WRITE (1, 400) DELP
 400	FORMAT (5X,'PRESSURE DROP, INCH-H2O:', T60, F8.3)

	WRITE (1, 410) LVIS
 410	FORMAT (5X,'LIQUID VISCOSITY, cP:', T60, F8.3)

	WRITE (1, 420) X
 420	FORMAT (5X,'X CO-ORDINATE IN THE GENERALIZED PLOT:', T60, F8.4)

	WRITE (1, 430) Y
 430	FORMAT (5X,'Y CO-ORDINATE IN THE GENERALIZED PLOT:', T60, F8.4)

	WRITE (1, 440) G1
 440	FORMAT (5X,'CALCULATED VAPOR RATE, lb/s.ft^2:', T60, F8.4)

	WRITE (1, 450) X1
 450	FORMAT (5X,'X CO-ORDINATE AT FLOODING CONDITION:', T60, F8.4)

	WRITE (1, 460) Y1
 460	FORMAT (5X,'Y CO-ORDINATE AT FLOODING CONDITION:', T60, F8.4)

	WRITE (1, 470) G2
 470	FORMAT (5X,'VAPOR RATE AT 70% FLOODING CONDITION, lb/s.ft^2:',\,
     *		T60, F8.4)

	WRITE (1, 480) VG
 480	FORMAT (5X,'VAPOR VELOCITY AT 70% FLOODING CONDITION, ft./sec:',\,
     *		T60, F8.2)

	WRITE (1, 490) AREA
 490	FORMAT (5X,'TOWER AREA, ft^2:', T60, F8.2)

	WRITE (1, 500) DIA
 500	FORMAT (5X,'TOWER DIAMETER, inches:', T60, F8.2)

	WRITE (1, 510) AREAF
 510	FORMAT (5X,'TOWER AREA AT 70% FLOODING CONDITION, ft^2:',\,
     *		T60,F8.2)

	WRITE (1, 520) DIAF
 520  FORMAT (5X,'TOWER DIAMETER AT 70% FLOODING CONDITION, inches:',\,
     *	      T60, F8.2)

	WRITE (1, 530)
 530	FORMAT (78(1H-))

C	FORM FEED THE PRINTING PAPER TO THE TOP OF THE NEXT PAGE.

	WRITE (1, *) CHAR(12)
	RETURN
	END
