	PROGRAM PROG105

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY, 2009
C	WEST MIDLANDS, U.K.
C
C	TOWER SIZING FOR VALVE TRAYS.
C	THE PROGRAM EMPLOYS THE NUTTER METHOD FOR CALCULATING
C	TOWER DIAMETER WHERE VALVE-TYPE TRAYS ARE USED.
C	TOWER SIZING GRAPHS AND CURVES IN NUTTER'S FLOAT VALVE
C	DESIGN HAVE BEEN FITTED TO A SERIES OF EQUATIONS AND ARE
C	USED IN THIS PROGRAM.
C	***************************************************************
C	RD	=   DENSITY RADICAL
C	DENV	=   VAPOR DENSITY, lb/ft.^3
C	DENL	=   LIQUID DENSITY, lb/ft.^3
C	SURT	=   SURFACE TENSION, dyne/cm.
C	V	=   VELOCITY AT ZERO LIQUID LOAD, ft./sec.
C	FT	=   TRAY SPACING FACTOR
C	WV	=   VAPOR FLOW RATE, lb/hr.
C	VCFS	=   VOLUMETRIC VAPOR FLOW RATE,	ft.^3/sec.
C	WL	=   LIQUID FLOW RATE, lb/hr.
C	LCFS	=   VOLUMETRIC LIQUID FLOW RATE, ft.^3/sec.
C	AB	=   BUBBLING AREA, ft.^2.
C	FF	=   FOAM FACTOR
C	ADC	=   DOWNCOMER AREA, ft.^2.
C	REST	=   DOWNCOMER RESIDENCE TIME, sec.
C	TS	=   TRAY SPACING, inch.
C	TSF	=   SAFETY FACTOR
C	AT	=   TOWER AREA, ft^2
C	D	=   TOWER DIAMETER, ft.
C	***************************************************************
C
C
	REAL K, M, LCFS
	COMMON PI

	COMMON/MULT1/ X, SF, RD, V, VRD
	COMMON/MULT2/ AB, ADC, AT, DIA, RDCA
	COMMON/MULT3/ WV, WL, DENL, DENV, FF, REST, TS, SURT
	COMMON/MULT4/ LCFS, VCFS

	OPEN (UNIT=3,FILE='DATA105.DAT',STATUS='OLD',ERR=18)
	
	OPEN (UNIT=1,FILE='RES105.RES')

C	READ THE VAPOR FLOW RATE, WV: lb/hr.
C	READ THE LIQUID FOW RATE, WL: lb/hr.
C	READ THE LIQUID DENSITY, DENL: lb/ft^3.
C	READ THE VAPOR DENSITY, DENL: lb/ft^3.
C	READ THE FOAM FACTOR, FF:
C	READ THE DOWNCOMER RESIDENCE TIME, REST: sec.
C	READ THE TRAY SPACING, TS:
C	READ THE SURFACE TENSTION, SURT: dyne/cm.


	READ(3, *, ERR=19) WV, WL, DENL
	READ(3, *, ERR=19) DENV, FF, REST
	READ(3, *, ERR=19) TS, SURT


	GO TO 20

 18	WRITE (*, 21)
 21	FORMAT(3X,'DATA FILE DOES NOT EXIST')
 
	GO TO 999

 19	WRITE (*, 22)
 22	FORMAT(3X,'ERROR MESSAGE IN THE DATA VALUE')

	GO TO 999

C	CONSTANTS FOR VELOCITY AT ZERO LIQUID LOAD, ft/sec.
C	(W.W. BLACKWELL, Chemical Process Design On A Programmable
C	Calculator, Mc. Graw-Hill, 1984).


 20	PI = 3.1415927
	A = 0.22982
	B = 0.44605
	C = 0.03452
	D = 0.00415
	E = 0.00017
	K = 0.91146
	M = -0.03821


C	CALCULATE THE RATIO OF SURFACE TENSION TO THE VAPOR DENSITY, X

	X=SURT/DENV

C	CALCULATE THE SAFETY FACTOR.

	SF=K*(X)**M

C	CALCULATE THE DENSITY RADICAL.

	RD=SQRT(DENV/(DENL-DENV))
C
C	V IS VALID FOR 0.1 < X < 3000.

C	CALCULATE THE VELOCITY AT ZERO LIQUID LOAD, ft/sec.

	VAL1=A+B*ALOG(X)-C*(ALOG(X))**2+D*(ALOG(X))**3-E*(ALOG(X))**4

	V=EXP(VAL1)

	VRD=V*RD

	IF (VRD .GE. 0.5) THEN
	
	GO TO 23
	
	ELSE
	
	ENDIF
	
	GO TO 24

 23	VRD = 0.5

C	CHECK THE TRAY SPACING, TS.


 24	IF (TS .EQ. 12.0 ) THEN

	GO TO 33

	ELSEIF (TS .EQ. 18.0) THEN

	GO TO 44

	ELSEIF (TS .EQ. 24.0) THEN

	GO TO 55

	ELSEIF (TS .EQ. 30.0) THEN

	GO TO 66

	ELSEIF (TS .EQ. 36.0) THEN

	GO TO 77

	ENDIF


 33	CALL PROG1

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT

C	PRINT THE RESULTS ONTO A PRINTER.

	CALL PAPER

	GO TO 999

 44	CALL PROG2

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT

C	PRINT THE RESULTS ONTO A PRINTER

	CALL PAPER

	GO TO 999


 55	CALL PROG3

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT

C	PRINT THE RESULTS ONTO A PRINTER

	CALL PAPER

	GO TO 999

 66	CALL PROG4

C	PRINT THE RESULTS ON THE SCREEN

	CALL OUTPUT

C	PRINT THE RESULTS ONTO A PRINTER.

	CALL PAPER

	GO TO 999

 77	CALL PROG5

C	PRINT THE RESULTS ON THE SCREEN.

	CALL OUTPUT

C	PRINT THE RESULTS ONTO A PRINTER.

	CALL PAPER

	CLOSE (3, STATUS='KEEP')
	CLOSE (1)

 999	STOP
	END
C
C	**************************************************************
C	TOWER SIZING FOR VALVE TRAYS USING A 12 INCH TRAY SPACING.
C	**************************************************************

	SUBROUTINE PROG1

	REAL LCFS
	COMMON PI

	COMMON/MULT1/ X, SF, RD, V, VRD
	COMMON/MULT2/ AB, ADC, AT, DIA, RDCA
	COMMON/MULT3/ WV, WL, DENL, DENV, FF, REST, TS, SURT
	COMMON/MULT4/ LCFS, VCFS

	G = 0.77174

	H = -0.02964

C	CALCULATE THE TRAY SPACING FACTOR, TSF

	TSF = G+H*ALOG(X)

C	CALCULATE THE VAPOR VOLUMETRIC RATE, VCFS

	VCFS = WV/(DENV*3600.0)

C	CALCULATE THE LIQUID VOLUMETRIC RATE, LCFS

	LCFS = WL/(DENL*3600.0)

	IF (VRD .GT. 0.5) THEN

	VRD = 0.5

	ELSE

	ENDIF

C	CALCULATE THE BUBBLING AREA, AB

	AB = (VCFS*RD+LCFS)/(TSF*VRD*FF)

C	CALCULATE THE DOWNCOMER AREA, ADC

	ADC = (REST*LCFS*12.0)/(FF*TS)

C	CALCULATE THE TOWER AREA, AT

	AT = (2.0*ADC+AB)/SF

C	CALCULATE THE TOWER DIAMETER, DIA.

	DIA = SQRT((4.0*AT)/PI)

C
C	CALCULATE THE DOWNCOMER AREA RATIO, RDCA
C
	RDCA = ADC/(2.*ADC + AB)

	RETURN
	END

C	***************************************************************
C	TOWER SIZING FOR VALVE TRAYS USING AN 18 INCH TRAY SPACING.
C	***************************************************************

	SUBROUTINE PROG2

	REAL LCFS

	COMMON PI
	COMMON/MULT1/ X, SF, RD, V, VRD
	COMMON/MULT2/ AB, ADC, AT, DIA, RDCA
	COMMON/MULT3/ WV, WL, DENL, DENV, FF, REST, TS, SURT
	COMMON/MULT4/ LCFS, VCFS

	G = 0.93655

	H = -0.02310

C	CALCULATE THE TRAY SPACING FACTOR, TSF

	TSF = G+H*ALOG(X)

C	CALCULATE THE VAPOR VOLUMETRIC RATE, VCFS

	VCFS = WV/(DENV*3600.0)

C	CALCULATE THE LIQUID VOLUMETRIC RATE, LCFS

	LCFS = WL/(DENL*3600.0)

	IF ( VRD .GT. 0.5) THEN

	VRD = 0.5

	ELSE

	ENDIF

C	CALCULATE THE BUBBLING AREA, AB.

	AB = (VCFS*RD+LCFS)/(TSF*VRD*FF)

C	CALCULATE THE DOWNCOMER AREA, ADC

	ADC = (REST*LCFS*12.0)/(FF*TS)

C	CALCULATE THE TOWER AREA, AT.

	AT = (2.0*ADC+AB)/SF

C	CALCULATE THE TOWER DIAMETER, DIA.

	DIA = SQRT((4.0*AT)/PI)

C	CALCULATE THE DOWNCOMER AREA RATIO, RDCA

	RDCA = ADC/(2.0*ADC+AB)

	RETURN

	END

C	***************************************************************
C	TOWER SIZING FOR VALVE TRAYS USING A 24 INCH TRAY SPACING.
C	***************************************************************

	SUBROUTINE PROG3

	REAL LCFS

	COMMON PI
	COMMON/MULT1/ X, SF, RD, V, VRD
	COMMON/MULT2/ AB, ADC, AT, DIA, RDCA
	COMMON/MULT3/ WV, WL, DENL, DENV, FF, REST, TS, SURT
	COMMON/MULT4/ LCFS, VCFS

C	CALCULATE THE TRAY SPACING FACTOR, TSF
C	FOR ALL VALUES OF X, TSF=1.0

	TSF = 1.0


C	CALCULATE THE VAPOR VOLUMETRIC RATE, VCFS

	VCFS = WV/(DENV*3600.0)

C	CALCULATE THE LIQUID VOLUMETRIC RATE, LCFS

	LCFS = WL/(DENL*3600.0)

	IF ( VRD .GT. 0.5) THEN
	
	VRD = 0.5
	
	ELSE
	
	ENDIF

C	CALCULATE THE BUBBLING AREA, AB

	AB = (VCFS*RD+LCFS)/(TSF*VRD*FF)

C	CALCULATE THE DOWNCOMER AREA, ADC

	ADC = (REST*LCFS*12.0)/(FF*TS)

C	CALCULATE THE TOWER AREA, AT.

	AT = (2.0*ADC+AB)/SF

C	CALCULATE THE TOWER DIAMETER, DIA.

	DIA = SQRT((4.0*AT)/PI)

C	CALCULATE THE DOWNCOMER AREA RATIO, RDCA

	RDCA = ADC/((2.0*ADC)+AB)

	RETURN

	END
C
C	***************************************************************
C	TOWER SIZING FOR VALVE TRAYS USING A 30 INCH TRAY SPACING.
C	***************************************************************

	SUBROUTINE PROG4

	REAL LCFS
	COMMON PI

	COMMON/MULT1/ X, SF, RD, V, VRD
	COMMON/MULT2/ AB, ADC, AT, DIA, RDCA
	COMMON/MULT3/ WV, WL, DENL, DENV, FF, REST, TS, SURT
	COMMON/MULT4/ LCFS, VCFS

	G = 0.98067

	H = 0.03220

C	CALCULATE THE TRAY SPACING FACTOR, TSF

	TSF = G + H*ALOG(X)

	IF ( X .LT. 1.85 ) THEN
	TSF = 1.0
	ELSE
	ENDIF

C	CALCULATE THE VAPOR VOLUMETRIC RATE, VCFS

	VCFS = WV/(DENV*3600.0)

C	CALCULATE THE LIQUID VOLUMETRIC RATE, LCFS

	LCFS = WL/(DENL*3600.0)

	IF ( VRD .GT. 0.5) THEN

	VRD = 0.5

	ELSE

	ENDIF

C	CALCULATE THE BUBBLING AREA, AB

	AB = (VCFS*RD+LCFS)/(TSF*VRD*FF)

C	CALCULATE THE DOWNCOMER AREA, ADC.

	ADC =(REST*LCFS*12.0)/(FF*TS)

C	CALCULATE THE TOWER AREA, AT

	AT = (2.0*ADC+ AB)/SF

C	CALCULATE THE TOWER DIAMETER, DIA.

	DIA = SQRT((4.0*AT)/PI)

C	CALCULATE THE DOWNCOMER AREA RATIO, RDCA

	RDCA = ADC/((2.0*ADC)+AB)

	RETURN

	END

C	***************************************************************
C	TOWER SIZING FOR VALVE TRAYS USING A 36 INCH TRAY SPACING.
C	***************************************************************

	SUBROUTINE PROG5

	REAL LCFS
	COMMON PI

	COMMON/MULT1/ X, SF, RD, V, VRD
	COMMON/MULT2/ AB, ADC, AT, DIA, RDCA
	COMMON/MULT3/ WV, WL, DENL, DENV, FF, REST, TS, SURT
	COMMON/MULT4/ LCFS, VCFS

	G = 0.96583

	H = 0.06162

C	CALCULATE THE TRAY SPACING FACTOR, TSF.

	TSF = G+H*ALOG(X)

	IF (X .LT. 1.85) THEN

	TSF = 1.0

	ELSE

	ENDIF

C	CALCULATE THE VAPOR VOLUMETRIC RATE, VCFS

	VCFS = WV/(DENV*3600.0)

C	CALCULATE THE LIQUID VOLUMETRIC RATE, LCFS.

	LCFS = WL/(DENL*3600.0)

	IF (VRD .GT. 0.5) THEN

	VRD = 0.5

	ELSE

	ENDIF

C	CALCULATE THE BUBBLING AREA, AB.

	AB = (VCFS*RD+LCFS)/(TSF*VRD*FF)

C	CALCULATE THE DOWNCOMER AREA, ADC

	ADC = (REST*LCFS*12.0)/(FF*TS)

C	CALCULATE THE TOWER AREA, AT.

	AT = (2.0*ADC+AB)/SF

C	CALCULATE THE TOWER DIAMETER, DIA.

	DIA = SQRT((4.0*AT)/PI)

C	CALCULATE THE DOWNCOMER AREA RATIO, RDCA

	RDCA = ADC/((2.0*ADC)+AB)

	RETURN

	END

C	**************************************************************
C	THIS PROGRAM PRINTS THE RESULTS ONTO THE SCREEN

	SUBROUTINE OUTPUT

	REAL LCFS

	COMMON/MULT1/ X, SF, RD, V, VRD
	COMMON/MULT2/ AB, ADC, AT, DIA, RDCA
	COMMON/MULT3/ WV, WL, DENL, DENV, FF, REST, TS, SURT
	COMMON/MULT4/ LCFS, VCFS

	WRITE (*, 100)
 100	FORMAT (//, 25X, 'TOWER DESIGN FOR VALVE TRAYS',/,78(1H*))

	WRITE (*, 110) WV, VCFS, WL, LCFS, DENL
 110	FORMAT (5X,'VAPOR FLOW RATE, lb/hr.:', T60, F10.1,/,
     *		5X,'VAPOR VOLUMETRIC RATE, ft^3/sec.:', T60, F10.3,/,
     *		5X,'LIQUID FLOW RATE, lb/hr.:', T60, F10.1,/,
     *		5X,'LIQUID VOLUMETRIC RATE, ft^3/sec.:', T60, F10.3,/,
     *		5X,'LIQUID DENSITY, lb/ft^3.:', T60, F10.3)

	WRITE (*, 120) DENV, FF, REST
 120	FORMAT (5X,'VAPOR DENSITY, lb/ft^3.:', T60, F10.3,/,
     *		5X,'FOAM FACTOR:', T60, F10.3,/,
     *		5X,'DOWNCOMER RESIDENCE TIME, sec.:', T60, F10.3)

	WRITE (*, 130) TS, SURT
 130	FORMAT (5X,'TRAY SPACING, in.:', T60, F8.0,/,
     *		5X,'SURFACE TENSION, dyne/cm.:', T60, F8.2)

	WRITE (*, 140) X, SF, RD
 140	FORMAT (5X,'SURFACE TENSION/VAPOR DENSITY (X):', T60, F10.3,/,
     *		5X,'SAFETY FACTOR:', T60, F10.3,/,
     *		5X,'DENSITY RADICAL:', T60, F10.3)


	WRITE (*, 150) AB, ADC, AT
 150	FORMAT (5X,'BUBBLING AREA, ft^2:', T60, F10.3,/,
     *		5X,'DOWNCOMER AREA, ft^2:', T60, F10.3,/,
     *		5X,'TOWER AREA, ft^2:', T60, F10.3)

	WRITE (*, 160) DIA, RDCA
 160	FORMAT (5X,'TOWER DIAMETER, ft:', T60, F10.3,/,
     *		5X,'DOWNCOMER AREA RATIO:', T60, F10.4)

	WRITE (*, 170)
 170	FORMAT (78(1H-))

	RETURN
	END

C
C	***************************************************************
C	THIS PROGRAM PRINTS THE RESULTS ON THE PRINTER.
C	***************************************************************
C
	SUBROUTINE PAPER

	REAL LCFS
	COMMON /MULT1/ X, SF, RD, V, VRD
	COMMON/ MULT2/ AB, ADC, AT, DIA, RDCA
	COMMON/ MULT3/ WV, WL, DENL, DENV, FF, REST, TS, SURT
	COMMON/ MULT4/ LCFS, VCFS

	WRITE (1, 180)
 180	FORMAT (///, 25X, 'TOWER DESIGN FOR VALVE TRAYS',/,78(1H*))

	WRITE (1, 190) WV, VCFS, WL, LCFS, DENL
 190	FORMAT (5X,'VAPOR FLOW RATE, lb/hr.:', T60, F10.1,/,
     *		5X,'VAPOR VOLUMETRIC RATE, ft^3/sec.:', T60, F10.3,/,
     *		5X,'LIQUID FLOW RATE, lb/hr.:', T60, F10.1,/,
     *		5X,'LIQUID VOLUMETRIC RATE, ft^3/sec.:',T60,F10.3,/,
     *		5X,'LIQUID DENSITY, lb/ft^3.:', T60, F10.3)

	WRITE (1, 200) DENV, FF, REST
 200	FORMAT (5X,'VAPOR DENSITY, lb/ft^3.:', T60, F10.3,/,
     *		5X,'FOAM FACTOR:', T60, F10.3,/,
     *		5X,'DOWNCOMER RESIDENCE TIME, sec.:', T60, F10.3)

	WRITE (1, 210) TS, SURT
 210	FORMAT (5X,'TRAY SPACING, in.:', T60, F8.0,/,
     *		5X,'SURFACE TENSION, dyne/cm.:', T60, F8.2)

	WRITE (1, 220) X, SF, RD
 220	FORMAT (5X,'SURFACE TENSION/VAPOR DENSITY (X):', T60, F10.3,/,
     *		5X,'SAFETY FACTOR:', T60, F10.3,/,
     *		5X,'DENSITY RADICAL:', T60, F10.3)

	WRITE (1, 230) AB, ADC, AT
 230	FORMAT (5X,'BUBBLING AREA, ft^2:', T60, F10.3,/,
     *		5X,'DOWNCOMER AREA, ft^2:', T60, F10.3,/,
     *		5X,'TOWER AREA, ft^2:', T60, F10.3)

	WRITE (1, 240) DIA, RDCA
 240	FORMAT (5X,'TOWER DIAMETER, ft:', T60, F10.3,/,
     *		5X,'DOWNCOMER AREA RATIO:', T60, F10.4)

	WRITE (1, 250)
 250	FORMAT (78(1H-))


	RETURN
	END
