	PROGRAM PROG77

C	BY A.K. COKER
C	



C	PERFORMANCE CALUCLATIONS OF A BINARY DISTILLATION 
C	COLUMN WITH MULTIPLE FEEDS AND SIDE STREAMS
C	McCABE-THIELE METHOD (CONSTANT MOLAL OVERFLOW)
C	




C	********************************************************************
C	
C	N	= NUMBER OF EQUILIBRIUM STAGES
C	X	= MOLE FRACTION VECTOR OF MORE VOLATILE COMPONENT         
C		  IN LIQUID
C	Y	= MOLE FRACTION VECTOR OF MORE VOLATILE COMPONENT 
C		  IN VAPOR
C	XEQ, YEQ = VECTORS OF VAPOR-LIQUID EQUILIBRIUM DATA
C	NEQ	= NUMBER OF DATA POINTS IN VLE-DATA
C	XF	= FEED COMPOSITION
C	D	= MOLAR RATE OF DISTILLATE
C	B	= MOLAR RATE OF BOTTOMS
C	XD	= DISTILLATE COMPOSITION
C	ICOND	= FLAG FOR CONDENSER TYPE
C		= 1 FOR TOTAL CONDENSER
C		= 2 FOR PARTIAL CONDENSER
C	R	= EXTERNAL REFLUX RATIO
C	NFEED	= TOTAL NUMBER OF FEEDS AND SIDE STREAMS
C	F(J)	= MOLAR FLOW RATE OF FEED J (NEGATIVE FOR SIDE STREAM)
C	Q(J)	= QUALITY OF FEED
C		  MOLE FRACTION OF LIQUID IF SIDE STREAM
C	NTRAY(J)= LOCATIONI OF FEED OR SIDE STREAM
C		  NUMBERED SERIALLY FROM TOP
C	VFD	= VAPOR FRACTION IN DISTILLATE FOR PARTIAL CONDENSER
C	ITMAX	= MAXIMUM NUMBER OF ITERATIONS
C	***************************************************************
C
	REAL LO, L(1:50)

	DOUBLE PRECISION DELTA(2)
	
	DIMENSION X(1:50), Y(1:50), XEQ(1:30), YEQ(1:30), Q(1:5)
	DIMENSION F(1:5), Z(1:5), V(1:51), NTRAY(1:5), DIST(1:2)
	DIMENSTION YOT(1:2)



	OPEN (UNIT = 3, FILE='DATA76.DAT', STATUS='OLD', ERR=18)
	OPEN (UNIT =1, FILE='REULT7.RES')



C	READ ALL THE INPUT DATA

	READ (3, *, ERR=19) N, NEQ, NFEED, ICOND, ITMAX
	
	
	READ(3, *, ERR=19) (NTRAY(J), J=1, NFEED)
	
	READ (3, *, ERR=19) (XEQ(I), YEQ(I), I=1, NEQ)
	 

C	FOR SIDE STREAMS INPUT NEGATIVE VALUE AND INPUT 
C       A TRIAL VALUE FOR XF


	DO J = 1, NFEED
	
	READ (3, *, ERR=19) F(J), Q(J), XF(J)
	
	END DO


C	IF TOTAL CONDENSER (ICOND=1), LEAVE BLANK FOR VFD


	READ (3, *, ERR=19) R, XD, VFD




	GO TO 10

 18	WRITE (*, 22)
 22	FORMAT (5X, 'DATA FILE DOES NOT EXIST')
	GO TO 999

 19	WRITE (*, 23)
 23	FORMAT (5X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999



C       ARRANGE THE FEEDS AND EQUILIBRIUM CONSTANT/RELATIVE
C       VOLATILITY IN THE ORDER OF DECREASING VALUE



 10	WRITE (*, 1302)N
 
 	SUMF = 0.0
 
 	SUMXF = 0.0
 
 
 
	DO I = 1, NFEED
	
	
	  SUMF =SUMF + F(I)
	  
	  SUMXF = SUMXF + F(I) * XF(I)
	
	END DO


	IF ( ICOND .EQ. 2) THEN
	
	GO TO 30
	
	ELSE
	
	WRITE (*, 1303)
	
	
	GO TO 50
	
	ENDIF
	
	
C	
C	PARTIAL CONDENSER

 30	WRITE (*, 1304) VFD
 
 	YOT(1) = 1.1 *XD
 	
 	IF (YOT(1) .GT. 1.) THEN
 	
 	YOT(1) = 0.995
 	
 	YOT(2) = 0.9 * YOT(1)
 	
 	KOUNT = 1
 	
 	ITER = 0
 	
 	
 	ELSE
 	
 40	XO = PARINT(XEQ, YEQ, NEQ, YOT(KOUNT)
 
 	XDP = VFD * YOT(KOUNT) + (1.0 - VFD)* XO
 	
 	DELTA(KOUNT) = XD - XDP
 	
 	ENDIF
 	
 	IF (DABS(DELTA(KOUNT)/XD) .LE. 5.D-4) THEN 
 	
 	GO TO 50
 	
 	ELSE
 	
 	KOUNT = KOUNT +1
 	
 	IF (KOUNT .EQ. 2) THEN 
 	
 	GO TO 40
 	
 	ELSE
 	
 	YO = (DELTA(1) *YOT(2) - DELTA(2)*YOT(1))/(DELTA(1)-DELTA(2))
 	
 	YOT(1) = YOT(2)
 	
 	YOT(2) = YO
 	
 	DELTA(1) = DELTA(2)
 	
 	KOUNT = 2
 	
 	ITER = ITER + 1
 	
 	ENDIF
 	ENDIF
 	
 	
 	IF (ITER .LT. ITMAX) THEN
 	
 	GO TO 40
 	
 	WRITE (*, 1305)
 	
 	GO TO 999
 	
 50	Y(1) = XD
 
 	X(1) = PARINT (XEQ, YEQ, NEQ, Y(1))
 	
 	NFEED1 = NFEED + 1
 	
 	SLOPE = R/(R+1.0)
 	
 	AINT = XD/(R+1.0)
 	
 	NT2 = NTRAY(1)
 	
 	DO I = 2, NT2
 	
 	IM1 = I - 1
 	
 	Y(I) = SLOPE * X(IM1) + AINT
 	
 	X(I) = PARINT (XEQ, YEQ, NEQ, Y(I))
 
	END DO
	
	D = SUMXF * XD + (SUMF - SUMXF)*(1.0- XD)
	
	DIST(1) = D
	
	DIST(2) = 0.8 * D
	
	KOUNT = 1
	
	WRITE (*, 1306)
	
	ITER = 0
	
	
 70	ITER = ITER + 1
 
 
 80	D = DIST(KOUNT)
 
 	LO = R * D
 	
 	V(1) = (R + 1.0) * D
 	
 	DO I = 2, NT2
 	
 	L (I -1 ) = LO
 	
 	V(I) = V(1)
 	
 	END DO
 	
 	XB = (SUMXF - D*XD)/(SUMF - D)
 	
 	NT1 = NTRAY(1) + 1
 	
 	TERM = D * XD
 	
 	DO J = 2 , NFEED1
 	
 	JM1 = J - 1
 	
 	IF (J .LE. NFEED) THEN
 	
 	NT2 = NTRAY(J)
 	
 	ELSEIF (J .EQ. NFEED) THEN
 	
 	NT2 = N
 	
 	ENDIF
 	
 	ENDIF
 	
 	ENDDO
 	
 	
 	L(NT1 - 1) = L(NT1 -2) + F(JM1) * Q(JM1)
 	
 	V(NT1) = V(NT1-1) - F(JM1)*(Q(JM1) -1.0)
 	
 	SLOPE = L(NT1 -1)/V(NT1)
 	
 	IF (F(JM1) .LT. 0 .AND. ABS(Q(JM1)-1.) .LT. 1.E-4) THEN
 	
 	XF(JM1) = X(NT1-1)
 	
 	ENDIF
 	
 	IF (F(JM1) .LT. 0 .AND. Q(JM1) .LT. 1.E-4) THEN
 	
 	XF(JM1) = Y(NT1 -1)
 	
 	ENDIF
 	
 	TERM = TERM- F(JM1) * XF(JM1)
 	
 	AINT = TERM/V(NT1)
 	
 	DO I = NT1, NT2
 	
 	Y(I) = SLOPE *X(I-1) + AINT
 	
 	X(I) = PARINT (XEQ, YEQ, NEQ, Y(I))
 	
 	IF (I .EQ. NT2) THEN 
 	
 	GO TO 100
 	
 	L(I) = L(NT1 - 1)
 	
 	V(I+1) = V(NT1)
 	
 100	END DO	
				
 110	NT1 = NTRAY(J) + 1

	DELTA(KOUNT) = XB - X(N)
	
	
	IF (DABS(DELTA(KOUNT)/XB) .LE. 1.D-3) THEN
	
	GO TO 130
	
	SUMXF = 0
	
	DO J = 1, NFEED
	
	SUMXF = SUMXF + F(J)* XF(J)
	
	END DO
	
	ENDIF
	
	B = SUMF - D
	
	L(N) = B
	
	KOUNT = KOUNT + 1
	
	IF (KOUNT .EQ. 2) THEN
	
	GO TO 80
	
	ELSE
	
	D = DIST(1) - (DIST(2) - DIST(1))* DELTA(1)/(DELTA(2)-DELTA(1))
	
	DIST(1) = DIST(2)
	
	DIST(2) = D
	
	DELTA(1) = DELTA(2)
	
	KOUNT = 2
	
	ENDIF
	
	WRITE (*, 1307) ITER, D, DELTA(1)
	
	IF (ITER .LT. ITMAX) THEN 
	
	GO TO 70
	
	ELSE
	
	WRITE (*, 1308)
	
	GO TO 999
	
 130	WRITE (*, 1307) ITER, D, DELTA(1)
 
 	WRITE (*, 1309) ITER
 	
 	WRITE (*, 1310)
 	
 	DO J = 1, NFEED
 	
 	WRITE (*, 1311) J, NTRAY(J), F(J), Q(J), XF(J)
 	
 	WRITE (*, 1312) R, D, B
 	
 	WRITE (*, 1313)
 	
 	I = 0
 	
 	VDIST = VFD * D
 	
 	ENDIF
 	
 	IF (ICOND .EQ. 1) THEN
 	
 	WRITE (*, 1314) I, XD, Y(1), LO, VDIST
 	
 	ELSE
 	
 	IF (ICOND .EQ. 2) THEN
 	
 	WRITE (*, 1314) I, XO, YO, LO, VDIST
 	
 	ENDIF
 	ENDIF
 	
 	END DO
 	
	DO I =1 , N
	
	WRITE (*, 1314) I, X(I), Y(I), L(I), V(I)
	
	GO TO 999
	
 1300	FORMAT (8F10.0)
 
 1301	FORMAT (20I3)
 
 1302 	FORMAT(10X, 'BINARY DISTILLATION BY McCABE-THIELE METHOD',//,
     *	1H ,'NUMBER OF EQUILIBRIUM STAGES:', T60, I3,/)
     
 1303	FORMAT (1H , 'TOTAL CONDENSER IS USED:')
 
 1304	FORMAT (1H , 'PARTIAL CONDENSER IS USED:',/ 1H ,
     *	'VAPOR FRACTION IN DISTILLATE:', T60,  F8.3)
     
 1305	FORMAT ('NO CONVERGENCE IN CONDENSER COMPOSITION')
 
 1306	FORMAT (3X, T2, 'ITERATION', T16, 'D', T27, 'XB-X(N)',/)
 
 1307	FORMAT (3X, I3, 2E15.5)
 
 1308	FORMAT (1H , 'NO CONVERGENCE IN DISTILLATE RATE')
 
 1309	FORMAT (1H , 'CONVERGED IN:', T60, I3, 'ITERATIONS', /)
 
 1310	FORMAT (3X,T2,'FEED',T10,'TRAY',T17,'RATE',T26,'Q',T33,'ZF'/,)
 
 1311	FORMAT (I3, 5X,I3, 3X,F7.4,3X,F4.2,3X,F5.4)
 
 1312	FORMAT (1H ,'REFLUX RATIO:', T60, F5.2/,
     *	'DISTILLATE RATE:', T60, E12.4, 'kmol/s',/
     *	'BOTTOMS RATE:', T60, E12.4, 'kmol/s)
     
 1313	FORMAT (3X,T2,'TRAY',T13,'X',T27,'Y',T41,'L',T55,'V',/ )
 
 1314	FORMAT (3X, I4, 4E14.4)          	 		
		
	

C	CALL OUTPUT(NUM,F,ALPHA,PERD,MD,PERB,MB,K1,RECLK,RECHK,AMIN,
C     *	SUM1,SUM2,MREF,REF,NUM1)


	CLOSE (3, STATUS='KEEP')
	CLOSE (1)

 999	STOP
	END


C	****************************************************************
C	THIS SUBPROGRAM PERFORMS A PARABOLIC INTERPOLATION TO EVALUATE
C	THE VALUE OF XP CORREPONDING TO YP FROM THE FUNCTION X =F(Y)
C	GIVEN AS A TABLE OF M VALUES OF X AND Y
C	****************************************************************

	FUNCTION PARAINT (X, Y, M, YP)

	DIMENSION X(M), Y(M), A(3), XT(3), YT(3)
	
	
	
	DO I = 1, M
	
	IF (YP .LT. Y(I)) THEN
	
	GO TO 20
	
	ELSE
	
	END DO
	
 20	IF (I .EQ. M) THEN
 
 	I = I - 1
 	
 	ELSEIF (I .EQ. 1) THEN
 	
 	I = I + 1
 	
 	
 	ENDIF
 	
 	DO J = 1, 3
 	
 	XT(J) = X(I + J - 2)
 	
 	YT(J) = Y(I + J - 2)
 	
 	END DO
 	
 	A(3) = (XT(3) - XT(2))/(YT(3)-YT(2))-(XT(2)-XT(1))/
     *	(YT(2) -YT(1)))/(YT(3) - YT(1))
     
     	A(2) = (XT(3) - XT(2)/ (YT(3) - YT(2)) - A(3)*(YT(3)+YT(2))
     	
     	XP = A(1) + YP *(A(2) + YP *A(3))
     	
     	PARINT = XP
     	
     	RETURN
     	
     	END		
 	
 	
	
	
	
	
	
  	    N1=N-1
	DO 10 I=1,N1
  	    I1=I+1
	DO 20 J=I1,N
  	    IF(X(I) .GE. X(J)) THEN
	GO TO 20
	ELSE
	HOLD=X(I)
	X(I)=X(J)
	X(J)=HOLD
	    HOLD=Y(I)
      	    Y(I)=Y(J)
	    Y(J)=HOLD

	    ENDIF
 20	CONTINUE
 10	CONTINUE

	RETURN
	END

C	****************************************************************
C	THIS PROGRAM CALCULATES THE UNDERWOOD CONSTANT THETA, USING THE
C	BINARY SEARCH METHOD AND THE MINIMUM REFLUX RATIO
C	(i.e. AT AN INFINITE NUMBER OF PLATES)
C	****************************************************************

	SUBROUTINE UNDERW (N, Q, XF, XD, THETA, MREF, ALPHA, K1)
	DIMENSION ALPHA(20), XF(20), XD(20)
	REAL MREF,LHS
	THETA1=ALPHA(K1)
	THETA2=ALPHA(K1-1)

	DO 10 I=1,20
	THETA=0.5*(THETA1+THETA2)
	LHS=Q-1.0

	DO J = 1, N
	LHS=LHS+((ALPHA(J)*XF(J))/(ALPHA(J)-THETA))
	END DO

	IF (LHS .LT. 0.0) THEN
	THETA1=THETA
	GO TO 10
	ELSEIF (LHS .GT. 0.0) THEN
	THETA2=THETA
	GO TO 10
        ELSEIF (LHS .EQ. 0.0) THEN
        GO TO 50
        ENDIF

 10     CONTINUE
 50	MREF=-1.0

	DO K = 1, N
	MREF=MREF+((ALPHA(K)*XD(K))/(ALPHA(K)-THETA))
	END DO

	RETURN
	END

C     *****************************************************************
C
C     THIS PROGRAM OUTPUTS THE RESULTS ON THE SCREEN
C     *****************************************************************

      SUBROUTINE OUTPUT(NUM,F,ALPHA,PERD,MD,PERB,MB,K1,RECLK,RECHK,AMIN,
     *SUM1,SUM2,MREF,REF,NUM1)

	DIMENSION F(20), ALPHA(20), PERD(20), PERB(20)
	REAL MD(20), MB(20), NUM1, MREF
	COMMON/DATA2/THETA, FEED

	WRITE (*, 100)
 100	FORMAT(25X,'MULTICOMPONENT SYSTEM FRACTIONATION')

	WRITE (*, 110)
 110	FORMAT(80(1H*))

	WRITE (*, 120)
 120	FORMAT(/,1X,'COMPONENT',7X,'FEED',5X,'REL VOLATILITY',3X,
     *	'DISTILATTE ',8X,'BOTTOMS ')

	WRITE (*, 130)
 130	FORMAT(1X,'NUMBER',9X,'MOLES',7X,'ALPHA',10X,'%',8X,'MOLES',8X,
     *'%',6X,'MOLES')

	WRITE (*, 140)
 140	FORMAT (80(1H-))

	DO 10 I=1,NUM

	WRITE (*, 150) I,F(I),ALPHA(I),PERD(I),MD(I),PERB(I),MB(I)
 150	FORMAT(3X,I2,7X,F9.4,3X,F9.4,3X,F9.4,2X,F9.4,3X,F9.4,2X,F9.4)
 10	CONTINUE

	WRITE (*, 160)
 160	FORMAT (80(1H-))

	WRITE (*, 170) K1
 170	FORMAT(3X,'THE HEAVY KEY COMPONENT NUMBER IS:',T60,I2)

	WRITE (*, 180) RECLK
 180	FORMAT(3X,'PERCENTAGE RECOVERY OF THE LIGHT KEY COMPONENT',/,
     *	3X,'IN THE DISTILLATE IS (%):',T60,F7.2)

	WRITE (*, 190) RECHK
 190	FORMAT(3X,'PERCENTAGE RECOVERY OF THE HEAVY KEY COMPONENT',/,
     *	3X,'IN THE BOTTOMS IS (%):',T60,F7.2)

	WRITE (*, 200) AMIN
 200	FORMAT(3X,'MINIMUM NUMBER OF STAGES IS:',T60,F9.1)

	WRITE (*, 210) SUM1, SUM2
 210	FORMAT(3X,'TOTAL MOLES IN THE DISTILLATE IS:',T60,F9.4,/,
     *	3X,'TOTAL MOLES IN THE BOTTOMS IS:',T60,F9.4)

	WRITE (*, 220) THETA
 220	FORMAT(3X,'UNDERWOOD CONSTANT:',T60,F9.4)

	WRITE (*, 230) MREF
 230	FORMAT(3X,'MINIMUM REFLUX RATIO:',T60,F9.4)

	WRITE (*, 240) REF
 240	FORMAT(3X,'ACTUAL REFLUX RATIO:',T60,F9.4)

	WRITE (*, 250) NUM1
 250	FORMAT(3X,'NUMBER OF THEORETICAL PLATES IN THE COLUMN:',T60,F9.1)

	WRITE (*, 260) FEED
 260	FORMAT(3X,'THE POSITION OF THE FEED PLATE IS:',T60,F4.1)

	WRITE (*, 270)
 270	FORMAT (1H ,80(1H-))

	OPEN (UNIT=1, FILE='LPT1')

	CALL PAPER (NUM,F,ALPHA,PERD,MD,PERB,MB,K1,RECLK,RECHK,AMIN,
     *		SUM1,SUM2,MREF,REF,NUM1)

	CLOSE (1)
	RETURN
	END

C	*************************************************************
C	THIS PROGRAM PRINTS THE RESULTS ONTO A PRINTER
C	************************************************************

	SUBROUTINE PAPER(NUM,F,ALPHA,PERD,MD,PERB,MB,K1,RECLK,RECHK,
     *	AMIN,SUM1,SUM2,MREF,REF,NUM1)

	DIMENSION F(20), ALPHA(20), PERD(20), PERB(20)
	REAL MD(20), MB(20), MREF, NUM1

	COMMON/DATA2/THETA, FEED

	WRITE (1, 280)
 280	FORMAT (///,25X,'MULTICOMPONENT SYSTEM FRACTIONATION',/,1H ,
     *		80(1H*))

	WRITE (1, 290)
 290	FORMAT (/, 1X,'COMPONENT',7X,'FEED',5X,'REL VOLATILITY', 3X,
     *	'DISTILLATE ', 8X, 'BOTTOMS ')

	WRITE (1, 300)
 300	FORMAT (1X,'NUMBER',9X,'MOLES',7X,'ALPHA',10X,'%',8X,'MOLES',8X,
     *	'%',6X,'MOLES')

	WRITE (1, 310)
 310	FORMAT (80(1H-))

	DO 10 I = 1 ,NUM

	WRITE (1, 320) I, F(I), ALPHA(I), PERD(I), MD(I), PERB(I), MB(I)
 320	FORMAT (3X,I2,7X,F9.4,3X,F9.4,3X,F9.4,2X,F9.4,3X,F9.4,2X,F9.4)

 10	CONTINUE

	WRITE (1, 330)
 330	FORMAT (80(1H-))

	WRITE (1, 340) K1
 340	FORMAT (3X,'THE HEAVY KEY COMPONENT NUMBER:', T60, I2)

	WRITE (1, 350) RECLK
 350	FORMAT (3X,'PERCENTAGE RECOVERY OF THE LIGHT KEY COMPONENT',/,
     *		3X,'IN THE DISTILLATE (%):', T60, F7.2)

	WRITE (1, 360) RECHK
 360	FORMAT (3X,'PERCENTAGE RECOVERY OF THE HEAVY KEY COMPONENT',/,
     *		3X,'IN THE BOTTOMS (%):', T60, F7.2)

	WRITE (1, 370) AMIN
 370	FORMAT (3X,'MINIMUM NUMBER OF STAGES:', T60, F9.1)

	WRITE (1, 380) SUM1, SUM2
 380	FORMAT (3X,'TOTAL MOLES IN THE DISTILLATE:', T60, F9.4,/,
     *		3X,'TOTAL MOLES IN THE BOTTOMS:', T60, F9.4)

	WRITE (1, 390) THETA
 390	FORMAT (3X,'UNDERWOOD CONSTANT:', T60, F9.4)

	WRITE (1, 400) MREF
 400	FORMAT (3X,'MINIMUM REFLUX RATIO:', T60, F9.4)

	WRITE (1, 410) REF
 410	FORMAT (3X,'ACTUAL REFLUX RATIO:', T60, F9.4)

	WRITE (1, 420) NUM1
 420	FORMAT (3X,'NUMBER OF THEORETICAL PLATES IN THE COLUMN:', T60,
     *		F9.1)

	WRITE (1, 430) FEED
 430	FORMAT (3X,'THE POSITION OF THE FEED PLATE:', T60, F9.1)

	WRITE (1, 440)
 440	FORMAT (80(1H-))


C	FORM FEED THE PRINTING PAPER TO THE TOP OF NEXT PAGE.

	WRITE (1, *) CHAR(12)
	RETURN

	END
