	PROGRAM PROG114

C	BY A.K. COKER
C	A.K.C. TECHNOLOGY, 2009
C	WEST MIDLANDS, U.K.	

C	******************************************************************
C	THE DESIGN OF A GAS DRYER.
C	THIS PROGRAM WILL PROVIDE A PRELIMINARY DESIGN FOR A SOLID-
C	DESICCANT DRYER USED FOR THE REMOVAL OF MOISTURE FROM GAS STREAMS.
C	THE PROGRAM WILL CALCULATE WATER PICKUP, DESICCANT VOLUME, DESICCANT
C	BED (TOWER) DIAMETER, GAS VELOCITY THROUGH THE BED, VESSEL WEIGHT,
C	DRYER REGENERATION REQUIREMENTS AND MOMENTUM FOR MAXIMUM DOWNFLOW
C	VELOCITIES.
C	*****************************************************************
C	H2OL   =	TOTAL WATER ADSORBED, lb/hr.
C	FLOW   =	GAS FLOW RATE,	10^6 std ft^3/day.
C	CYCLE  =	DRYING CYCLE, hr.
C	H2OC   =	WATER CONTENT OF GAS, lb/10^6 std ft^3.
C	DESVOL =	DESICCANT VOLUME, ft^3.
C	DDEN   =	DESICCANT DENSITY, lb/ft^3.
C	AREA1  =	CALCULATED AREA BASED ON DESICCANT VOLUME, ft^3.
C	BL     =	DESICCANT BED LENGTH, ft.
C	BD     =	CALCULATED BED DIAMETER USING AREA1, ft.
C	AREA   =	ACTUAL DESSICANT BED AREA USING BD CALCULATED OR
C			MODIFIED BY THE USER, ft^2.
C	Q      =	ACTUAL GAS FLOW RATE AT FLOWING CONDITIONS, ft^3/min.
C	T      =	GAS FLOWING TEMPERATURE oF.
C	P      =	DRYER OPERATING PRESSURE, psig.
C	Z      =	COMPRESSIBILITY FACTOR
C	VEL    =	GAS VELOCITY, ft/min.
C	TC     =	DRYER SHELL THICKNESS, in.
C	H      =	ADDITIONAL SHELL HEIGHT FOR DESICCANT SUPPORTS
C			AND DISTRIBUTOR, ft.
C	R      =	RADIUS OF DESICCANT BED, ft.
C	S      =	ALLOWABLE STRESS, lb/in^2.
C	E      =	JOINT EFFICIENCY.
C	THEAT  =	TOTAL HEAT REQUIRED TO REGENERATE DRYER (IDEAL), Btu.
C	WS     =	STEEL WEIGHT OF SHELL AND HEADS, lb.
C	WD     =	DESICCANT WEIGHT, lb.
C	TB     =	TEMPERATURE OF DESICCANT BED, oF.
C	HT     =	HEATER TEMPERATURE, oF.
C	F      =	LOSS FACTOR FOR NON-STEADY STATE HEATING.
C	REGENH =	HEAT ADDED TO REGENERATION GAS TO REGENERATE
C			DESICCANT BED.
C	H1,H2  =	ENTHALPY OF REGENERATION GAS BEFORE
C			AND AFTER REGENERATION, Btu/lb
C	REGENG =	TOTAL REGENERATION GAS REQUIREMENT, lb
C	MW     =	MOLECULAR WEIGHT OF REGENERATION GAS
C	SCF    =	STANDARD CUBIC FEET OF REGENERATION GAS
C	PICKUP =	DESICCANT WATER CAPACITY, %
C	*********************************************************************

	REAL MW, MOMEN

	COMMON/DRY1/ FLOW, P, T
	COMMON/DRY2/ Z, CYCLE, H2OC
	COMMON/DRY3/ S, E, PICKUP
	COMMON/DRY4/ DDEN, BL, HT
	COMMON/DRY5/ MW, H1, H2

	COMMON/RES1/ H2OL, DESVOL, AREA1
	COMMON/RES2/ BD, R, Q, VEL
	COMMON/RES3/ TC, VESWT, WD
	COMMON/RES4/ TB, THEAT, F
	COMMON/RES5/ REH, REG, SCF, MOMEN

	OPEN (UNIT=3, FILE='DATA14.DAT', STATUS='OLD', ERR=18)
	OPEN (UNIT=1, FILE='RES114.RES')

C	READ GAS FLOW RATE, FLOW: 10^6 std ft^3/day.
C	READ DRYER OPERATING PRESSURE, P: psig.
C	READ GAS FLOWING TEMPERATURE, T: oF.
C	READ GAS COMPRESSIBILITY FACTOR, Z.
C	READ DRYING CYCLE, CYCLE: hr.
C	READ WATER CONTENT OF GAS, H2OC: lb/MM std ft^3.
C	READ ALLOWABLE STRESS, S: lb/in^2.
C	READ JOINT EFFICIENCY, E: 1.0
C	READ DESICCANT WATER CAPACITY, PICKUP: %
C	READ DESCICCANT DENSITY, DDEN: lb/ft^3.
C	READ DESICCANT BED LENGTH, BL: ft.
C	READ HEATER TEMPERATURE, HT: oF.
C	READ MOLECULAR WEIGHT OF REGENERATING GAS, MW:
C	READ ENTHALPY OF REGENERATION GAS BEFORE REGENERATION HEATER,
C	H1: Btu/lb.
C	READ ENTHAPLY OF REGENERATION GAS AFTER REGENERATAION HEATER,
C	H2: Btu/lb.

	READ (3, *, ERR=19) FLOW, P, T
	READ (3, *, ERR=19) Z, CYCLE, H2OC
	READ (3, *, ERR=19) S, E, PICKUP
	READ (3, *, ERR=19) DDEN, BL, HT
	READ (3, *, ERR=19) MW, H1, H2


	GO TO 10
 18	WRITE (*, 11)
 11	FORMAT (6X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999

 19	WRITE (*, 12)
 12	FORMAT (6X, 'DATA FILE DOES NOT EXIST')
	GO TO 999

C	CALCULATE THE REQUIREMENTS FOR A GAS DRYER


 10	CALL DRYER

C	PRINT THE RESULTS.

	CALL OUTPUT

	CLOSE (UNIT=3, STATUS='KEEP')
	CLOSE (1)
 999	STOP
	END

C
C	***************************************************************
C	THIS PROGRAM SIZES THE GAS DRYER WITH THE GIVEN DATA VALUES
C	***************************************************************

	SUBROUTINE DRYER

	PARAMETER (PI=3.1415927)
	REAL MW, MOMEN

	COMMON/DRY1/ FLOW, P, T
	COMMON/DRY2/ Z, CYCLE, H2OC
	COMMON/DRY3/ S, E, PICKUP
	COMMON/DRY4/ DDEN, BL, HT
	COMMON/DRY5/ MW, H1, H2

	COMMON/RES1/ H2OL, DESVOL, AREA1
	COMMON/RES2/ BD, R, Q, VEL
	COMMON/RES3/ TC, VESWT, WD
	COMMON/RES4/ TB, THEAT, F
	COMMON/RES5/ REH, REG, SCF, MOMEN


C	CALCULATE TOTAL WATER ADSORBED, H2OL.

	H2OL = (FLOW*CYCLE*H2OC)/24.0


C	CALCULATE DESICCANT VOLUME, DESVOL

	DESVOL = (H2OL*100.0)/(PICKUP*DDEN)


C	CALCULATE DESICCANT CROSS-SECTIONAL AREA, AREA1.

	AREA1 = DESVOL/BL

C	CALCULATE BED DIAMETER, BD.

	BD = SQRT((4.0*AREA1)/PI)


C	CALCULATE THE BED AREA, AREA.

	AREA = (PI*BD**2)/4.

	T1 = T+460.
	R = (12.*BD)/2.
	P1 = P+14.7

C	CALCULATE THE ACTUAL GAS FLOW RATE AT FLOWING CONDITIONS, ft^3/min.

	Q = (FLOW*T1*Z*19.6314)/P1


C	CALCULATE THE SUPERFICIAL GAS VELOCITY, ft./min.

	VEL = Q/AREA

C	CALCULATE THE DRYER SHELL THICKNESS, in.

	TC = (P*R)/(S*E-0.6*P)


C	ASSUME H=2.0 ft. ADDITIONAL SHELL HEIGHT FOR DESICCANT SUPPORT AND
C	DISTRIBUTOR.

	H = 2.0

	R1 = BD/2.0

C	CALCULATE THE VESSEL WEIGHT., lb.


	VESWT = (480.*PI*BD*(TC/12.0)*(BL+H+R1)*1.1)
	TB = 0.75*HT+0.25*(HT-50.)

	WD = DDEN*DESVOL

	THEAT = 1.05*(VESWT*0.12*(TB-T)+WD*0.25*(TB-T)+H2OL*1400.)
	F = ALOG((HT-T)/50.)

C	CALCULATE TOTAL REGENERATION GAS REQUIREMENT AND STANDARD CUBIC
C	FEET OF REGENERATION GAS


	REH = THEAT*F
	REG = REH/(H1-H2)
	SCF = (REG*380.0)/MW

C	CALCULATE ALCOA'S MOMENTUM FOR MAXIMUM DOWNFLOW
C	VELOCITIES i.e. DESICCANT ATTRITION SHOULD NOT BE A PROBLEM
C	IF THE MOMEMTUM IS EQUAL TO OR LESS THAN 30,000.
C	MOMENTUM = (V)(MOL.WT) (P. Atms)

	MOMEN = VEL*MW*(P1/14.7)

	RETURN
	END


C	****************************************************************
C	THIS PROGRAM PRINTS THE OUTPUT OF THE RESULTS
C	*****************************************************************

	SUBROUTINE OUTPUT

	REAL MOMEN, MW

	COMMON/DRY1/ FLOW, P, T
	COMMON/DRY2/ Z, CYCLE, H2OC
	COMMON/DRY3/ S, E, PICKUP
	COMMON/DRY4/ DDEN, BL, HT
	COMMON/DRY5/ MW, H1, H2

	COMMON/RES1/ H2OL, DESVOL, AREA1
	COMMON/RES2/ BD, R, Q, VEL
	COMMON/RES3/ TC, VESWT, WD
	COMMON/RES4/ TB, THEAT, F
	COMMON/RES5/ REH, REG, SCF, MOMEN

C
	WRITE (1, 100)
 100	FORMAT (///,35X, 'GAS DRYER DESIGN',/1H ,78(1H*))

	WRITE (1, 110) FLOW, P, T
 110	FORMAT (5X, 'GAS FLOW RATE, 10^6 std. ft^3/day:',  T60, F12.3,/,
     *		5X,'DRYER OPERATING PRESSURE, psig.:', T60, F12.3,/,
     *		5X,'GAS FLOWING TEMPERATURE, oF:', T60, F12.1)

	WRITE (1, 120) Z, CYCLE, H2OC
 120	FORMAT (5X,'GAS COMPRESSIBILITY FACTOR:', T60, F12.4,/,
     *		5X,'DRYING CYCLE, hr.:', T60, F12.1,/,
     *		5X,'WATER CONTENT OF GAS, lb/10^6 std.ft^3:',T60,F12.0)

	WRITE (1, 130) S, E, PICKUP
 130	FORMAT (5X,'ALLOWABLE STRESS, psi:', T60, F12.1,/,
     *		5X,'JOINT EFFICIENCY:', T60, F12.1,/,
     *	5X,'USEFUL DESIGN CAPACITY OF DESICCANT, (%):', T60, F12.1)

	WRITE (1, 140) DDEN, HT
 140	FORMAT (5X, 'DESICCANT DENSITY, lb/ft^3:', T60, F12.1,/,
     *		5X, 'HEATER OUTLET TEMPERATURE, oF:', T60, F12.1)

	WRITE (1, 150) MW, H1, H2
 150	FORMAT (5X, 'MOLECULAR WEIGHT OF REGENERATION GAS:',T60,F12.1,/,
     *5X,'ENTHALPY OF GAS BEFORE REGENERATION HEATER, Btu/lb:',T60,
     *F12.1,/,5X,'ENTHALPY OF GAS AFTER REGENERATION HEATER, Btu/lb:',
     *T60, F12.1)


	WRITE (1, 160) H2OL, DESVOL, AREA1
 160	FORMAT (5X,'TOTAL WATER ADSORBED, lb/h.:', T60, F12.3,/,
     *		5X,'DESICCANT VOLUME, ft^3.:', T60, F12.4,/,
     *		5X,'CALCULATED CROSS-SECTIONAL AREA, ft^2.:', T60, F12.4)

	WRITE (1, 170) BD, R, BL, Q, VEL
 170	FORMAT (5X,'BED DIAMETER, ft.:', T60, F8.4,/,
     *		5X,'BED RADIUS, ft.:', T60, F8.4,/,
     *		5X,'BED LENGTH, ft.:', T60, F8.2,/,
     *		5X,'ACTUAL GAS FLOW RATE, ft^3/min.:', T60, F12.3,/,
     *		5X,'SUPERFICIAL GAS VELOCITY, ft./min.:', T60, F12.3)

	WRITE (1, 180) TC, VESWT, WD
 180	FORMAT (5X,'DRYER SHELL THICKNESS, in.:', T60, F12.4,/,
     *		5X,'VESSEL WEIGHT, lb.:', T60, F12.0,/,
     *		5X,'DESICCANT WEIGHT, lb.:', T60, F12.0)

	WRITE (1, 190) TB, THEAT, F
 190	FORMAT (5X,'TEMPERATURE OF DESICCANT BED, oF:', T60, F12.3,/,
     *		5X,'TOTAL HEAT REQUIRED TO REGENERATE DRYER, Btu:', T60,
     *		E14.6,/, 5X, 'LOSS FACTOR:', T60, F12.4)

	WRITE (1, 200) REH, REG, SCF, MOMEN
 200	FORMAT (5X,'HEAT ADDED TO REGENERATION GAS:', T60, E14.6,/,
     *		5X,'TOTAL REGENERATION GAS REQUIREMENT, lb:',T60, E14.6,
     *	      /,5X,'STANDARD CUBIC FEET OF REGENERATION GAS, std.ft^3:',
     *	     T60, E14.6,/,5X,'MOMENTUM:', T60, E14.6)


	WRITE (1, 210)
 210	FORMAT (76(1H-))


C	FORM FEED THE PRINTING PAPER TO THE TOP OF THE NEXT PAGE.

C	WRITE (1, *) CHAR(12)




	WRITE (*, 1000)
 1000	FORMAT (///,35X, 'GAS DRYER DESIGN',/1H ,78(1H*))

	WRITE (*, 1100) FLOW, P, T
 1100	FORMAT (5X, 'GAS FLOW RATE, 10^6 std. ft^3/day:',  T60, F12.3,/,
     *		5X,'DRYER OPERATING PRESSURE, psig.:', T60, F12.3,/,
     *		5X,'GAS FLOWING TEMPERATURE, oF:', T60, F12.1)

	WRITE (*, 1200) Z, CYCLE, H2OC
 1200	FORMAT (5X,'GAS COMPRESSIBILITY FACTOR:', T60, F12.4,/,
     *		5X,'DRYING CYCLE, hr.:', T60, F12.1,/,
     *		5X,'WATER CONTENT OF GAS, lb/10^6 std.ft^3:',T60,F12.0)

	WRITE (*, 1300) S, E, PICKUP
 1300	FORMAT (5X,'ALLOWABLE STRESS, psi:', T60, F12.1,/,
     *		5X,'JOINT EFFICIENCY:', T60, F12.1,/,
     *	5X,'USEFUL DESIGN CAPACITY OF DESICCANT, (%):', T60, F12.1)

	WRITE (*, 1400) DDEN, HT
 1400	FORMAT (5X, 'DESICCANT DENSITY, lb/ft^3:', T60, F12.1,/,
     *		5X, 'HEATER OUTLET TEMPERATURE, oF:', T60, F12.1)

	WRITE (*, 1500) MW, H1, H2
 1500	FORMAT (5X, 'MOLECULAR WEIGHT OF REGENERATION GAS:',T60,F12.1,/,
     *5X,'ENTHALPY OF GAS BEFORE REGENERATION HEATER, Btu/lb:',T60,
     *F12.1,/,5X,'ENTHALPY OF GAS AFTER REGENERATION HEATER, Btu/lb:',
     *T60, F12.1)


	WRITE (*, 1600) H2OL, DESVOL, AREA1
 1600	FORMAT (5X,'TOTAL WATER ADSORBED, lb/h.:', T60, F12.3,/,
     *		5X,'DESICCANT VOLUME, ft^3.:', T60, F12.4,/,
     *		5X,'CALCULATED CROSS-SECTIONAL AREA, ft^2.:', T60, F12.4)

	WRITE (*, 1700) BD, R, BL, Q, VEL
 1700	FORMAT (5X,'BED DIAMETER, ft.:', T60, F8.4,/,
     *		5X,'BED RADIUS, ft.:', T60, F8.4,/,
     *		5X,'BED LENGTH, ft.:', T60, F8.2,/,
     *		5X,'ACTUAL GAS FLOW RATE, ft^3/min.:', T60, F12.3,/,
     *		5X,'SUPERFICIAL GAS VELOCITY, ft./min.:', T60, F12.3)

	WRITE (*, 1800) TC, VESWT, WD
 1800	FORMAT (5X,'DRYER SHELL THICKNESS, in.:', T60, F12.4,/,
     *		5X,'VESSEL WEIGHT, lb.:', T60, F12.0,/,
     *		5X,'DESICCANT WEIGHT, lb.:', T60, F12.0)

	WRITE (*, 1900) TB, THEAT, F
 1900	FORMAT (5X,'TEMPERATURE OF DESICCANT BED, oF:', T60, F12.3,/,
     *		5X,'TOTAL HEAT REQUIRED TO REGENERATE DRYER, Btu:', T60,
     *		E14.6,/, 5X, 'LOSS FACTOR:', T60, F12.4)

	WRITE (*, 2000) REH, REG, SCF, MOMEN
 2000	FORMAT (5X,'HEAT ADDED TO REGENERATION GAS:', T60, E14.6,/,
     *		5X,'TOTAL REGENERATION GAS REQUIREMENT, lb:',T60, E14.6,
     *	      /,5X,'STANDARD CUBIC FEET OF REGENERATION GAS, std.ft^3:',
     *	     T60, E14.6,/,5X,'MOMENTUM:', T60, E14.6)

	WRITE (*, 2100)
 2100	FORMAT (76(1H-))

	RETURN
	END
